/*
 * Internal module API header file.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtNetworkAPI_H
#define _QtNetworkAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include <sip.h>

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11
#define SIP_TIMELINE_Qt_5_15_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtNetwork[0]
#define sipNameNr_QSslConfiguration__NextProtocolNegotiationStatus 50
#define sipName_QSslConfiguration__NextProtocolNegotiationStatus &sipStrings_QtNetwork[50]
#define sipNameNr_QNetworkAccessManager__NetworkAccessibility 99
#define sipName_QNetworkAccessManager__NetworkAccessibility &sipStrings_QtNetwork[99]
#define sipNameNr_143 143
#define sipName_143 &sipStrings_QtNetwork[143]
#define sipNameNr_QNetworkAddressEntry__DnsEligibilityStatus 186
#define sipName_QNetworkAddressEntry__DnsEligibilityStatus &sipStrings_QtNetwork[186]
#define sipNameNr_QNetworkConfigurationManager__Capabilities 229
#define sipName_QNetworkConfigurationManager__Capabilities &sipStrings_QtNetwork[229]
#define sipNameNr_QNetworkRequest__TransferTimeoutConstant 272
#define sipName_QNetworkRequest__TransferTimeoutConstant &sipStrings_QtNetwork[272]
#define sipNameNr_QNetworkConfigurationManager__Capability 313
#define sipName_QNetworkConfigurationManager__Capability &sipStrings_QtNetwork[313]
#define sipNameNr_SslOptionDisableServerCipherPreference 354
#define sipName_SslOptionDisableServerCipherPreference &sipStrings_QtNetwork[354]
#define sipNameNr_EmitAllUploadProgressSignalsAttribute 393
#define sipName_EmitAllUploadProgressSignalsAttribute &sipStrings_QtNetwork[393]
#define sipNameNr_isStrictTransportSecurityStoreEnabled 431
#define sipName_isStrictTransportSecurityStoreEnabled &sipStrings_QtNetwork[431]
#define sipNameNr_QAbstractSocket__NetworkLayerProtocol 469
#define sipName_QAbstractSocket__NetworkLayerProtocol &sipStrings_QtNetwork[469]
#define sipNameNr_507 507
#define sipName_507 &sipStrings_QtNetwork[507]
#define sipNameNr_SslOptionDisableServerNameIndication 544
#define sipName_SslOptionDisableServerNameIndication &sipStrings_QtNetwork[544]
#define sipNameNr_AuthorityIssuerSerialNumberMismatch 581
#define sipName_AuthorityIssuerSerialNumberMismatch &sipStrings_QtNetwork[581]
#define sipNameNr_UnableToDecryptCertificateSignature 617
#define sipName_UnableToDecryptCertificateSignature &sipStrings_QtNetwork[617]
#define sipNameNr_SslOptionDisableLegacyRenegotiation 653
#define sipName_SslOptionDisableLegacyRenegotiation &sipStrings_QtNetwork[653]
#define sipNameNr_QSslDiffieHellmanParameters__Error 689
#define sipName_QSslDiffieHellmanParameters__Error &sipStrings_QtNetwork[689]
#define sipNameNr_NextProtocolNegotiationUnsupported 724
#define sipName_NextProtocolNegotiationUnsupported &sipStrings_QtNetwork[724]
#define sipNameNr_SslOptionDisableSessionPersistence 759
#define sipName_SslOptionDisableSessionPersistence &sipStrings_QtNetwork[759]
#define sipNameNr_enableStrictTransportSecurityStore 794
#define sipName_enableStrictTransportSecurityStore &sipStrings_QtNetwork[794]
#define sipNameNr_preSharedKeyAuthenticationRequired 829
#define sipName_preSharedKeyAuthenticationRequired &sipStrings_QtNetwork[829]
#define sipNameNr_UnableToGetLocalIssuerCertificate 864
#define sipName_UnableToGetLocalIssuerCertificate &sipStrings_QtNetwork[864]
#define sipNameNr_NextProtocolNegotiationNegotiated 898
#define sipName_NextProtocolNegotiationNegotiated &sipStrings_QtNetwork[898]
#define sipNameNr_QNetworkRequest__CacheLoadControl 932
#define sipName_QNetworkRequest__CacheLoadControl &sipStrings_QtNetwork[932]
#define sipNameNr_setSslConfigurationImplementation 966
#define sipName_setSslConfigurationImplementation &sipStrings_QtNetwork[966]
#define sipNameNr_ContentOperationNotPermittedError 1000
#define sipName_ContentOperationNotPermittedError &sipStrings_QtNetwork[1000]
#define sipNameNr_QNetworkInterface__InterfaceFlags 1034
#define sipName_QNetworkInterface__InterfaceFlags &sipStrings_QtNetwork[1034]
#define sipNameNr_QNetworkConfiguration__BearerType 1068
#define sipName_QNetworkConfiguration__BearerType &sipStrings_QtNetwork[1068]
#define sipNameNr_QNetworkConfiguration__StateFlags 1102
#define sipName_QNetworkConfiguration__StateFlags &sipStrings_QtNetwork[1102]
#define sipNameNr_setStrictTransportSecurityEnabled 1136
#define sipName_setStrictTransportSecurityEnabled &sipStrings_QtNetwork[1136]
#define sipNameNr_AutoDeleteReplyOnFinishAttribute 1170
#define sipName_AutoDeleteReplyOnFinishAttribute &sipStrings_QtNetwork[1170]
#define sipNameNr_BackgroundRequestNotAllowedError 1203
#define sipName_BackgroundRequestNotAllowedError &sipStrings_QtNetwork[1203]
#define sipNameNr_QNetworkInterface__InterfaceType 1236
#define sipName_QNetworkInterface__InterfaceType &sipStrings_QtNetwork[1236]
#define sipNameNr_QNetworkInterface__InterfaceFlag 1269
#define sipName_QNetworkInterface__InterfaceFlag &sipStrings_QtNetwork[1269]
#define sipNameNr_QNetworkConfiguration__StateFlag 1302
#define sipName_QNetworkConfiguration__StateFlag &sipStrings_QtNetwork[1302]
#define sipNameNr_isStrictTransportSecurityEnabled 1335
#define sipName_isStrictTransportSecurityEnabled &sipStrings_QtNetwork[1335]
#define sipNameNr_QNetworkAccessManager__Operation 1368
#define sipName_QNetworkAccessManager__Operation &sipStrings_QtNetwork[1368]
#define sipNameNr_QHostAddress__ConversionModeFlag 1401
#define sipName_QHostAddress__ConversionModeFlag &sipStrings_QtNetwork[1401]
#define sipNameNr_ProxyAuthenticationRequiredError 1434
#define sipName_ProxyAuthenticationRequiredError &sipStrings_QtNetwork[1434]
#define sipNameNr_1467 1467
#define sipName_1467 &sipStrings_QtNetwork[1467]
#define sipNameNr_QNetworkRequest__RedirectPolicy 1499
#define sipName_QNetworkRequest__RedirectPolicy &sipStrings_QtNetwork[1499]
#define sipNameNr_addStrictTransportSecurityHosts 1531
#define sipName_addStrictTransportSecurityHosts &sipStrings_QtNetwork[1531]
#define sipNameNr_UnsupportedSocketOperationError 1563
#define sipName_UnsupportedSocketOperationError &sipStrings_QtNetwork[1563]
#define sipNameNr_UnableToVerifyFirstCertificate 1595
#define sipName_UnableToVerifyFirstCertificate &sipStrings_QtNetwork[1595]
#define sipNameNr_QSslCertificate__PatternSyntax 1626
#define sipName_QSslCertificate__PatternSyntax &sipStrings_QtNetwork[1626]
#define sipNameNr_SslOptionDisableSessionSharing 1657
#define sipName_SslOptionDisableSessionSharing &sipStrings_QtNetwork[1657]
#define sipNameNr_SslOptionDisableSessionTickets 1688
#define sipName_SslOptionDisableSessionTickets &sipStrings_QtNetwork[1688]
#define sipNameNr_SslOptionDisableEmptyFragments 1719
#define sipName_SslOptionDisableEmptyFragments &sipStrings_QtNetwork[1719]
#define sipNameNr_QSsl__AlternativeNameEntryType 1750
#define sipName_QSsl__AlternativeNameEntryType &sipStrings_QtNetwork[1750]
#define sipNameNr_QNetworkSession__UsagePolicies 1781
#define sipName_QNetworkSession__UsagePolicies &sipStrings_QtNetwork[1781]
#define sipNameNr_DefaultTransferTimeoutConstant 1812
#define sipName_DefaultTransferTimeoutConstant &sipStrings_QtNetwork[1812]
#define sipNameNr_OriginalContentLengthAttribute 1843
#define sipName_OriginalContentLengthAttribute &sipStrings_QtNetwork[1843]
#define sipNameNr_HttpPipeliningWasUsedAttribute 1874
#define sipName_HttpPipeliningWasUsedAttribute &sipStrings_QtNetwork[1874]
#define sipNameNr_HttpPipeliningAllowedAttribute 1905
#define sipName_HttpPipeliningAllowedAttribute &sipStrings_QtNetwork[1905]
#define sipNameNr_DoNotBufferUploadDataAttribute 1936
#define sipName_DoNotBufferUploadDataAttribute &sipStrings_QtNetwork[1936]
#define sipNameNr_sslConfigurationImplementation 1967
#define sipName_sslConfigurationImplementation &sipStrings_QtNetwork[1967]
#define sipNameNr_QNetworkConfiguration__Purpose 1998
#define sipName_QNetworkConfiguration__Purpose &sipStrings_QtNetwork[1998]
#define sipNameNr_supportedSchemesImplementation 2029
#define sipName_supportedSchemesImplementation &sipStrings_QtNetwork[2029]
#define sipNameNr_QLocalSocket__LocalSocketState 2060
#define sipName_QLocalSocket__LocalSocketState &sipStrings_QtNetwork[2060]
#define sipNameNr_QLocalSocket__LocalSocketError 2091
#define sipName_QLocalSocket__LocalSocketError &sipStrings_QtNetwork[2091]
#define sipNameNr_UnfinishedSocketOperationError 2122
#define sipName_UnfinishedSocketOperationError &sipStrings_QtNetwork[2122]
#define sipNameNr_SocketAddressNotAvailableError 2153
#define sipName_SocketAddressNotAvailableError &sipStrings_QtNetwork[2153]
#define sipNameNr_2184 2184
#define sipName_2184 &sipStrings_QtNetwork[2184]
#define sipNameNr_QSslPreSharedKeyAuthenticator 2214
#define sipName_QSslPreSharedKeyAuthenticator &sipStrings_QtNetwork[2214]
#define sipNameNr_UnableToDecodeIssuerPublicKey 2244
#define sipName_UnableToDecodeIssuerPublicKey &sipStrings_QtNetwork[2244]
#define sipNameNr_setBackendConfigurationOption 2274
#define sipName_setBackendConfigurationOption &sipStrings_QtNetwork[2274]
#define sipNameNr_nextProtocolNegotiationStatus 2304
#define sipName_nextProtocolNegotiationStatus &sipStrings_QtNetwork[2304]
#define sipNameNr_NextProtocolNegotiationStatus 69
#define sipName_NextProtocolNegotiationStatus &sipStrings_QtNetwork[69]
#define sipNameNr_preferredConfigurationChanged 2334
#define sipName_preferredConfigurationChanged &sipStrings_QtNetwork[2334]
#define sipNameNr_QNetworkSession__SessionError 2364
#define sipName_QNetworkSession__SessionError &sipStrings_QtNetwork[2364]
#define sipNameNr_QNetworkRequest__KnownHeaders 2394
#define sipName_QNetworkRequest__KnownHeaders &sipStrings_QtNetwork[2394]
#define sipNameNr_ignoreSslErrorsImplementation 2424
#define sipName_ignoreSslErrorsImplementation &sipStrings_QtNetwork[2424]
#define sipNameNr_ProtocolInvalidOperationError 2454
#define sipName_ProtocolInvalidOperationError &sipStrings_QtNetwork[2454]
#define sipNameNr_QNetworkProxyQuery__QueryType 2484
#define sipName_QNetworkProxyQuery__QueryType &sipStrings_QtNetwork[2484]
#define sipNameNr_ReceiveBufferSizeSocketOption 2514
#define sipName_ReceiveBufferSizeSocketOption &sipStrings_QtNetwork[2514]
#define sipNameNr_QAbstractSocket__SocketOption 2544
#define sipName_QAbstractSocket__SocketOption &sipStrings_QtNetwork[2544]
#define sipNameNr_2574 2574
#define sipName_2574 &sipStrings_QtNetwork[2574]
#define sipNameNr_2603 2603
#define sipName_2603 &sipStrings_QtNetwork[2603]
#define sipNameNr_sslLibraryBuildVersionString 2632
#define sipName_sslLibraryBuildVersionString &sipStrings_QtNetwork[2632]
#define sipNameNr_sslLibraryBuildVersionNumber 2661
#define sipName_sslLibraryBuildVersionNumber &sipStrings_QtNetwork[2661]
#define sipNameNr_SelfSignedCertificateInChain 2690
#define sipName_SelfSignedCertificateInChain &sipStrings_QtNetwork[2690]
#define sipNameNr_UnableToGetIssuerCertificate 2719
#define sipName_UnableToGetIssuerCertificate &sipStrings_QtNetwork[2719]
#define sipNameNr_QSslCertificate__SubjectInfo 2748
#define sipName_QSslCertificate__SubjectInfo &sipStrings_QtNetwork[2748]
#define sipNameNr_QNetworkSession__UsagePolicy 2777
#define sipName_QNetworkSession__UsagePolicy &sipStrings_QtNetwork[2777]
#define sipNameNr_QNetworkRequest__LoadControl 2806
#define sipName_QNetworkRequest__LoadControl &sipStrings_QtNetwork[2806]
#define sipNameNr_AuthenticationReuseAttribute 2835
#define sipName_AuthenticationReuseAttribute &sipStrings_QtNetwork[2835]
#define sipNameNr_ConnectionEncryptedAttribute 2864
#define sipName_ConnectionEncryptedAttribute &sipStrings_QtNetwork[2864]
#define sipNameNr_OperationNotImplementedError 2893
#define sipName_OperationNotImplementedError &sipStrings_QtNetwork[2893]
#define sipNameNr_TemporaryNetworkFailureError 2922
#define sipName_TemporaryNetworkFailureError &sipStrings_QtNetwork[2922]
#define sipNameNr_QNetworkConfigurationManager 2951
#define sipName_QNetworkConfigurationManager &sipStrings_QtNetwork[2951]
#define sipNameNr_strictTransportSecurityHosts 2980
#define sipName_strictTransportSecurityHosts &sipStrings_QtNetwork[2980]
#define sipNameNr_setHuffmanCompressionEnabled 3009
#define sipName_setHuffmanCompressionEnabled &sipStrings_QtNetwork[3009]
#define sipNameNr_QHostAddress__ConversionMode 3038
#define sipName_QHostAddress__ConversionMode &sipStrings_QtNetwork[3038]
#define sipNameNr_QHostAddress__SpecialAddress 3067
#define sipName_QHostAddress__SpecialAddress &sipStrings_QtNetwork[3067]
#define sipNameNr_QAbstractSocket__SocketState 3096
#define sipName_QAbstractSocket__SocketState &sipStrings_QtNetwork[3096]
#define sipNameNr_QAbstractSocket__SocketError 3125
#define sipName_QAbstractSocket__SocketError &sipStrings_QtNetwork[3125]
#define sipNameNr_3154 3154
#define sipName_3154 &sipStrings_QtNetwork[3154]
#define sipNameNr_3182 3182
#define sipName_3182 &sipStrings_QtNetwork[3182]
#define sipNameNr_OcspResponseCannotBeTrusted 3210
#define sipName_OcspResponseCannotBeTrusted &sipStrings_QtNetwork[3210]
#define sipNameNr_QSslDiffieHellmanParameters 3238
#define sipName_QSslDiffieHellmanParameters &sipStrings_QtNetwork[3238]
#define sipNameNr_setPreSharedKeyIdentityHint 3266
#define sipName_setPreSharedKeyIdentityHint &sipStrings_QtNetwork[3266]
#define sipNameNr_NextProtocolNegotiationNone 3294
#define sipName_NextProtocolNegotiationNone &sipStrings_QtNetwork[3294]
#define sipNameNr_SslOptionDisableCompression 3322
#define sipName_SslOptionDisableCompression &sipStrings_QtNetwork[3322]
#define sipNameNr_AuthenticationRequiredError 1439
#define sipName_AuthenticationRequiredError &sipStrings_QtNetwork[1439]
#define sipNameNr_QNetworkReply__NetworkError 3350
#define sipName_QNetworkReply__NetworkError &sipStrings_QtNetwork[3350]
#define sipNameNr_QNetworkProxy__Capabilities 3378
#define sipName_QNetworkProxy__Capabilities &sipStrings_QtNetwork[3378]
#define sipNameNr_QNetworkConfiguration__Type 3406
#define sipName_QNetworkConfiguration__Type &sipStrings_QtNetwork[3406]
#define sipNameNr_configurationFromIdentifier 3434
#define sipName_configurationFromIdentifier &sipStrings_QtNetwork[3434]
#define sipNameNr_QLocalServer__SocketOptions 3462
#define sipName_QLocalServer__SocketOptions &sipStrings_QtNetwork[3462]
#define sipNameNr_QHttpMultiPart__ContentType 3490
#define sipName_QHttpMultiPart__ContentType &sipStrings_QtNetwork[3490]
#define sipNameNr_setSessionReceiveWindowSize 3518
#define sipName_setSessionReceiveWindowSize &sipStrings_QtNetwork[3518]
#define sipNameNr_QAbstractSocket__PauseModes 3546
#define sipName_QAbstractSocket__PauseModes &sipStrings_QtNetwork[3546]
#define sipNameNr_proxyAuthenticationRequired 3574
#define sipName_proxyAuthenticationRequired &sipStrings_QtNetwork[3574]
#define sipNameNr_ProxyConnectionTimeoutError 3602
#define sipName_ProxyConnectionTimeoutError &sipStrings_QtNetwork[3602]
#define sipNameNr_ProxyConnectionRefusedError 3630
#define sipName_ProxyConnectionRefusedError &sipStrings_QtNetwork[3630]
#define sipNameNr_UnknownNetworkLayerProtocol 3658
#define sipName_UnknownNetworkLayerProtocol &sipStrings_QtNetwork[3658]
#define sipNameNr_QAbstractSocket__SocketType 3686
#define sipName_QAbstractSocket__SocketType &sipStrings_QtNetwork[3686]
#define sipNameNr_3714 3714
#define sipName_3714 &sipStrings_QtNetwork[3714]
#define sipNameNr_QSslSocket__PeerVerifyMode 3741
#define sipName_QSslSocket__PeerVerifyMode &sipStrings_QtNetwork[3741]
#define sipNameNr_CertificateSignatureFailed 3768
#define sipName_CertificateSignatureFailed &sipStrings_QtNetwork[3768]
#define sipNameNr_setDiffieHellmanParameters 3795
#define sipName_setDiffieHellmanParameters &sipStrings_QtNetwork[3795]
#define sipNameNr_DistinguishedNameQualifier 3822
#define sipName_DistinguishedNameQualifier &sipStrings_QtNetwork[3822]
#define sipNameNr_OperationNotSupportedError 3849
#define sipName_OperationNotSupportedError &sipStrings_QtNetwork[3849]
#define sipNameNr_UserVerifiedRedirectPolicy 3876
#define sipName_UserVerifiedRedirectPolicy &sipStrings_QtNetwork[3876]
#define sipNameNr_setMaximumRedirectsAllowed 3903
#define sipName_setMaximumRedirectsAllowed &sipStrings_QtNetwork[3903]
#define sipNameNr_BackgroundRequestAttribute 3930
#define sipName_BackgroundRequestAttribute &sipStrings_QtNetwork[3930]
#define sipNameNr_CookieSaveControlAttribute 3957
#define sipName_CookieSaveControlAttribute &sipStrings_QtNetwork[3957]
#define sipNameNr_CookieLoadControlAttribute 3984
#define sipName_CookieLoadControlAttribute &sipStrings_QtNetwork[3984]
#define sipNameNr_SourceIsFromCacheAttribute 4011
#define sipName_SourceIsFromCacheAttribute &sipStrings_QtNetwork[4011]
#define sipNameNr_RedirectionTargetAttribute 4038
#define sipName_RedirectionTargetAttribute &sipStrings_QtNetwork[4038]
#define sipNameNr_QNetworkRequest__Attribute 4065
#define sipName_QNetworkRequest__Attribute &sipStrings_QtNetwork[4065]
#define sipNameNr_setApplicationProxyFactory 4092
#define sipName_setApplicationProxyFactory &sipStrings_QtNetwork[4092]
#define sipNameNr_QLocalServer__SocketOption 4119
#define sipName_QLocalServer__SocketOption &sipStrings_QtNetwork[4119]
#define sipNameNr_setStreamReceiveWindowSize 4146
#define sipName_setStreamReceiveWindowSize &sipStrings_QtNetwork[4146]
#define sipNameNr_QAbstractSocket__PauseMode 4173
#define sipName_QAbstractSocket__PauseMode &sipStrings_QtNetwork[4173]
#define sipNameNr_SendBufferSizeSocketOption 4200
#define sipName_SendBufferSizeSocketOption &sipStrings_QtNetwork[4200]
#define sipNameNr_ProxyConnectionClosedError 4227
#define sipName_ProxyConnectionClosedError &sipStrings_QtNetwork[4227]
#define sipNameNr_4254 4254
#define sipName_4254 &sipStrings_QtNetwork[4254]
#define sipNameNr_maximumPreSharedKeyLength 4280
#define sipName_maximumPreSharedKeyLength &sipStrings_QtNetwork[4280]
#define sipNameNr_OcspResponseCertIdUnknown 4306
#define sipName_OcspResponseCertIdUnknown &sipStrings_QtNetwork[4306]
#define sipNameNr_sessionTicketLifeTimeHint 4332
#define sipName_sessionTicketLifeTimeHint &sipStrings_QtNetwork[4332]
#define sipNameNr_NoBackgroundTrafficPolicy 4358
#define sipName_NoBackgroundTrafficPolicy &sipStrings_QtNetwork[4358]
#define sipNameNr_newConfigurationActivated 4384
#define sipName_newConfigurationActivated &sipStrings_QtNetwork[4384]
#define sipNameNr_InvalidConfigurationError 4410
#define sipName_InvalidConfigurationError &sipStrings_QtNetwork[4410]
#define sipNameNr_QNetworkRequest__Priority 4436
#define sipName_QNetworkRequest__Priority &sipStrings_QtNetwork[4436]
#define sipNameNr_CacheSaveControlAttribute 4462
#define sipName_CacheSaveControlAttribute &sipStrings_QtNetwork[4462]
#define sipNameNr_CacheLoadControlAttribute 4488
#define sipName_CacheLoadControlAttribute &sipStrings_QtNetwork[4488]
#define sipNameNr_HttpReasonPhraseAttribute 4514
#define sipName_HttpReasonPhraseAttribute &sipStrings_QtNetwork[4514]
#define sipNameNr_NetworkSessionFailedError 4540
#define sipName_NetworkSessionFailedError &sipStrings_QtNetwork[4540]
#define sipNameNr_setUseSystemConfiguration 4566
#define sipName_setUseSystemConfiguration &sipStrings_QtNetwork[4566]
#define sipNameNr_QNetworkProxy__Capability 4592
#define sipName_QNetworkProxy__Capability &sipStrings_QtNetwork[4592]
#define sipNameNr_CanStartAndStopInterfaces 4618
#define sipName_CanStartAndStopInterfaces &sipStrings_QtNetwork[4618]
#define sipNameNr_huffmanCompressionEnabled 4644
#define sipName_huffmanCompressionEnabled &sipStrings_QtNetwork[4644]
#define sipNameNr_ConvertUnspecifiedAddress 4670
#define sipName_ConvertUnspecifiedAddress &sipStrings_QtNetwork[4670]
#define sipNameNr_QAbstractSocket__BindMode 4696
#define sipName_QAbstractSocket__BindMode &sipStrings_QtNetwork[4696]
#define sipNameNr_QAbstractSocket__BindFlag 4722
#define sipName_QAbstractSocket__BindFlag &sipStrings_QtNetwork[4722]
#define sipNameNr_4748 4748
#define sipName_4748 &sipStrings_QtNetwork[4748]
#define sipNameNr_4773 4773
#define sipName_4773 &sipStrings_QtNetwork[4773]
#define sipNameNr_newSessionTicketReceived 4798
#define sipName_newSessionTicketReceived &sipStrings_QtNetwork[4798]
#define sipNameNr_setDefaultCaCertificates 4823
#define sipName_setDefaultCaCertificates &sipStrings_QtNetwork[4823]
#define sipNameNr_addDefaultCaCertificates 4848
#define sipName_addDefaultCaCertificates &sipStrings_QtNetwork[4848]
#define sipNameNr_CertificateStatusUnknown 4873
#define sipName_CertificateStatusUnknown &sipStrings_QtNetwork[4873]
#define sipNameNr_preSharedKeyIdentityHint 4898
#define sipName_preSharedKeyIdentityHint &sipStrings_QtNetwork[4898]
#define sipNameNr_setLocalCertificateChain 4923
#define sipName_setLocalCertificateChain &sipStrings_QtNetwork[4923]
#define sipNameNr_QSslCertificateExtension 4948
#define sipName_QSslCertificateExtension &sipStrings_QtNetwork[4948]
#define sipNameNr_AlternativeNameEntryType 1756
#define sipName_AlternativeNameEntryType &sipStrings_QtNetwork[1756]
#define sipNameNr_SameOriginRedirectPolicy 4973
#define sipName_SameOriginRedirectPolicy &sipStrings_QtNetwork[4973]
#define sipNameNr_NoLessSafeRedirectPolicy 4998
#define sipName_NoLessSafeRedirectPolicy &sipStrings_QtNetwork[4998]
#define sipNameNr_FollowRedirectsAttribute 5023
#define sipName_FollowRedirectsAttribute &sipStrings_QtNetwork[5023]
#define sipNameNr_ContentDispositionHeader 5048
#define sipName_ContentDispositionHeader &sipStrings_QtNetwork[5048]
#define sipNameNr_HostNameLookupCapability 5073
#define sipName_HostNameLookupCapability &sipStrings_QtNetwork[5073]
#define sipNameNr_QNetworkProxy__ProxyType 5098
#define sipName_QNetworkProxy__ProxyType &sipStrings_QtNetwork[5098]
#define sipNameNr_networkAccessibleChanged 5123
#define sipName_networkAccessibleChanged &sipStrings_QtNetwork[5123]
#define sipNameNr_setMaxPendingConnections 5148
#define sipName_setMaxPendingConnections &sipStrings_QtNetwork[5148]
#define sipNameNr_sessionReceiveWindowSize 5173
#define sipName_sessionReceiveWindowSize &sipStrings_QtNetwork[5173]
#define sipNameNr_QHstsPolicy__PolicyFlags 5198
#define sipName_QHstsPolicy__PolicyFlags &sipStrings_QtNetwork[5198]
#define sipNameNr_QHostInfo__HostInfoError 5223
#define sipName_QHostInfo__HostInfoError &sipStrings_QtNetwork[5223]
#define sipNameNr_5248 5248
#define sipName_5248 &sipStrings_QtNetwork[5248]
#define sipNameNr_sslLibraryVersionString 5272
#define sipName_sslLibraryVersionString &sipStrings_QtNetwork[5272]
#define sipNameNr_sslLibraryVersionNumber 5296
#define sipName_sslLibraryVersionNumber &sipStrings_QtNetwork[5296]
#define sipNameNr_encryptedBytesAvailable 5320
#define sipName_encryptedBytesAvailable &sipStrings_QtNetwork[5320]
#define sipNameNr_addDefaultCaCertificate 5344
#define sipName_addDefaultCaCertificate &sipStrings_QtNetwork[5344]
#define sipNameNr_setBackendConfiguration 5368
#define sipName_setBackendConfiguration &sipStrings_QtNetwork[5368]
#define sipNameNr_diffieHellmanParameters 5392
#define sipName_diffieHellmanParameters &sipStrings_QtNetwork[5392]
#define sipNameNr_supportedEllipticCurves 5416
#define sipName_supportedEllipticCurves &sipStrings_QtNetwork[5416]
#define sipNameNr_setAllowedNextProtocols 5440
#define sipName_setAllowedNextProtocols &sipStrings_QtNetwork[5440]
#define sipNameNr_setDefaultConfiguration 5464
#define sipName_setDefaultConfiguration &sipStrings_QtNetwork[5464]
#define sipNameNr_subjectAlternativeNames 5488
#define sipName_subjectAlternativeNames &sipStrings_QtNetwork[5488]
#define sipNameNr_TransferTimeoutConstant 289
#define sipName_TransferTimeoutConstant &sipStrings_QtNetwork[289]
#define sipNameNr_maximumRedirectsAllowed 5512
#define sipName_maximumRedirectsAllowed &sipStrings_QtNetwork[5512]
#define sipNameNr_RedirectPolicyAttribute 5536
#define sipName_RedirectPolicyAttribute &sipStrings_QtNetwork[5536]
#define sipNameNr_HttpStatusCodeAttribute 5560
#define sipName_HttpStatusCodeAttribute &sipStrings_QtNetwork[5560]
#define sipNameNr_ServiceUnavailableError 5584
#define sipName_ServiceUnavailableError &sipStrings_QtNetwork[5584]
#define sipNameNr_usesSystemConfiguration 5608
#define sipName_usesSystemConfiguration &sipStrings_QtNetwork[5608]
#define sipNameNr_setNetworkConfiguration 5632
#define sipName_setNetworkConfiguration &sipStrings_QtNetwork[5632]
#define sipNameNr_SctpListeningCapability 5656
#define sipName_SctpListeningCapability &sipStrings_QtNetwork[5656]
#define sipNameNr_SctpTunnelingCapability 5680
#define sipName_SctpTunnelingCapability &sipStrings_QtNetwork[5680]
#define sipNameNr_maximumTransmissionUnit 5704
#define sipName_maximumTransmissionUnit &sipStrings_QtNetwork[5704]
#define sipNameNr_QNetworkCookie__RawForm 5728
#define sipName_QNetworkCookie__RawForm &sipStrings_QtNetwork[5728]
#define sipNameNr_ApplicationLevelRoaming 5752
#define sipName_ApplicationLevelRoaming &sipStrings_QtNetwork[5752]
#define sipNameNr_DirectConnectionRouting 5776
#define sipName_DirectConnectionRouting &sipStrings_QtNetwork[5776]
#define sipNameNr_streamReceiveWindowSize 5800
#define sipName_streamReceiveWindowSize &sipStrings_QtNetwork[5800]
#define sipNameNr_QHstsPolicy__PolicyFlag 5824
#define sipName_QHstsPolicy__PolicyFlag &sipStrings_QtNetwork[5824]
#define sipNameNr_OperationCancelledError 5848
#define sipName_OperationCancelledError &sipStrings_QtNetwork[5848]
#define sipNameNr_MulticastLoopbackOption 5872
#define sipName_MulticastLoopbackOption &sipStrings_QtNetwork[5872]
#define sipNameNr_SslInvalidUserDataError 5896
#define sipName_SslInvalidUserDataError &sipStrings_QtNetwork[5896]
#define sipNameNr_SslHandshakeFailedError 5920
#define sipName_SslHandshakeFailedError &sipStrings_QtNetwork[5920]
#define sipNameNr_5944 5944
#define sipName_5944 &sipStrings_QtNetwork[5944]
#define sipNameNr_5967 5967
#define sipName_5967 &sipStrings_QtNetwork[5967]
#define sipNameNr_CertificateBlacklisted 5990
#define sipName_CertificateBlacklisted &sipStrings_QtNetwork[5990]
#define sipNameNr_CertificateNotYetValid 6013
#define sipName_CertificateNotYetValid &sipStrings_QtNetwork[6013]
#define sipNameNr_setOcspStaplingEnabled 6036
#define sipName_setOcspStaplingEnabled &sipStrings_QtNetwork[6036]
#define sipNameNr_nextNegotiatedProtocol 6059
#define sipName_nextNegotiatedProtocol &sipStrings_QtNetwork[6059]
#define sipNameNr_OrganizationalUnitName 6082
#define sipName_OrganizationalUnitName &sipStrings_QtNetwork[6082]
#define sipNameNr_QOcspCertificateStatus 6105
#define sipName_QOcspCertificateStatus &sipStrings_QtNetwork[6105]
#define sipNameNr_QNetworkSession__State 6128
#define sipName_QNetworkSession__State &sipStrings_QtNetwork[6128]
#define sipNameNr_OperationCanceledError 6151
#define sipName_OperationCanceledError &sipStrings_QtNetwork[6151]
#define sipNameNr_UdpTunnelingCapability 6174
#define sipName_UdpTunnelingCapability &sipStrings_QtNetwork[6174]
#define sipNameNr_interfaceNameFromIndex 6197
#define sipName_interfaceNameFromIndex &sipStrings_QtNetwork[6197]
#define sipNameNr_interfaceIndexFromName 6220
#define sipName_interfaceIndexFromName &sipStrings_QtNetwork[6220]
#define sipNameNr_ServiceSpecificPurpose 6243
#define sipName_ServiceSpecificPurpose &sipStrings_QtNetwork[6243]
#define sipNameNr_NetworkSessionRequired 6266
#define sipName_NetworkSessionRequired &sipStrings_QtNetwork[6266]
#define sipNameNr_connectToHostEncrypted 6289
#define sipName_connectToHostEncrypted &sipStrings_QtNetwork[6289]
#define sipNameNr_authenticationRequired 6312
#define sipName_authenticationRequired &sipStrings_QtNetwork[6312]
#define sipNameNr_QDnsMailExchangeRecord 6335
#define sipName_QDnsMailExchangeRecord &sipStrings_QtNetwork[6335]
#define sipNameNr_ConnectionRefusedError 3635
#define sipName_ConnectionRefusedError &sipStrings_QtNetwork[3635]
#define sipNameNr_6358 6358
#define sipName_6358 &sipStrings_QtNetwork[6358]
#define sipNameNr_6380 6380
#define sipName_6380 &sipStrings_QtNetwork[6380]
#define sipNameNr_setMulticastInterface 6402
#define sipName_setMulticastInterface &sipStrings_QtNetwork[6402]
#define sipNameNr_encryptedBytesWritten 6424
#define sipName_encryptedBytesWritten &sipStrings_QtNetwork[6424]
#define sipNameNr_encryptedBytesToWrite 6446
#define sipName_encryptedBytesToWrite &sipStrings_QtNetwork[6446]
#define sipNameNr_startServerEncryption 6468
#define sipName_startServerEncryption &sipStrings_QtNetwork[6468]
#define sipNameNr_startClientEncryption 6490
#define sipName_startClientEncryption &sipStrings_QtNetwork[6490]
#define sipNameNr_defaultCaCertificates 6512
#define sipName_defaultCaCertificates &sipStrings_QtNetwork[6512]
#define sipNameNr_maximumIdentityLength 6534
#define sipName_maximumIdentityLength &sipStrings_QtNetwork[6534]
#define sipNameNr_OcspMalformedResponse 6556
#define sipName_OcspMalformedResponse &sipStrings_QtNetwork[6556]
#define sipNameNr_SubjectIssuerMismatch 6578
#define sipName_SubjectIssuerMismatch &sipStrings_QtNetwork[6578]
#define sipNameNr_SelfSignedCertificate 6600
#define sipName_SelfSignedCertificate &sipStrings_QtNetwork[6600]
#define sipNameNr_InvalidNotBeforeField 6622
#define sipName_InvalidNotBeforeField &sipStrings_QtNetwork[6622]
#define sipNameNr_UnsafeParametersError 6644
#define sipName_UnsafeParametersError &sipStrings_QtNetwork[6644]
#define sipNameNr_InvalidInputDataError 6666
#define sipName_InvalidInputDataError &sipStrings_QtNetwork[6666]
#define sipNameNr_localCertificateChain 6688
#define sipName_localCertificateChain &sipStrings_QtNetwork[6688]
#define sipNameNr_subjectInfoAttributes 6710
#define sipName_subjectInfoAttributes &sipStrings_QtNetwork[6710]
#define sipNameNr_QOcspRevocationReason 6732
#define sipName_QOcspRevocationReason &sipStrings_QtNetwork[6732]
#define sipNameNr_setHttp2Configuration 6754
#define sipName_setHttp2Configuration &sipStrings_QtNetwork[6754]
#define sipNameNr_Http2WasUsedAttribute 6776
#define sipName_Http2WasUsedAttribute &sipStrings_QtNetwork[6776]
#define sipNameNr_HTTP2WasUsedAttribute 6798
#define sipName_HTTP2WasUsedAttribute &sipStrings_QtNetwork[6798]
#define sipNameNr_Http2AllowedAttribute 6820
#define sipName_Http2AllowedAttribute &sipStrings_QtNetwork[6820]
#define sipNameNr_HTTP2AllowedAttribute 6842
#define sipName_HTTP2AllowedAttribute &sipStrings_QtNetwork[6842]
#define sipNameNr_IfModifiedSinceHeader 6864
#define sipName_IfModifiedSinceHeader &sipStrings_QtNetwork[6864]
#define sipNameNr_InsecureRedirectError 6886
#define sipName_InsecureRedirectError &sipStrings_QtNetwork[6886]
#define sipNameNr_TooManyRedirectsError 6908
#define sipName_TooManyRedirectsError &sipStrings_QtNetwork[6908]
#define sipNameNr_DnsEligibilityUnknown 6930
#define sipName_DnsEligibilityUnknown &sipStrings_QtNetwork[6930]
#define sipNameNr_QNetworkConfiguration 6952
#define sipName_QNetworkConfiguration &sipStrings_QtNetwork[6952]
#define sipNameNr_QNetworkAccessManager 6974
#define sipName_QNetworkAccessManager &sipStrings_QtNetwork[6974]
#define sipNameNr_nextPendingConnection 6996
#define sipName_nextPendingConnection &sipStrings_QtNetwork[6996]
#define sipNameNr_maxPendingConnections 7018
#define sipName_maxPendingConnections &sipStrings_QtNetwork[7018]
#define sipNameNr_hasPendingConnections 7040
#define sipName_hasPendingConnections &sipStrings_QtNetwork[7040]
#define sipNameNr_setIncludesSubDomains 7062
#define sipName_setIncludesSubDomains &sipStrings_QtNetwork[7062]
#define sipNameNr_ConvertV4CompatToIPv4 7084
#define sipName_ConvertV4CompatToIPv4 &sipStrings_QtNetwork[7084]
#define sipNameNr_ConvertV4MappedToIPv4 7106
#define sipName_ConvertV4MappedToIPv4 &sipStrings_QtNetwork[7106]
#define sipNameNr_QDnsHostAddressRecord 7128
#define sipName_QDnsHostAddressRecord &sipStrings_QtNetwork[7128]
#define sipNameNr_DatagramTooLargeError 7150
#define sipName_DatagramTooLargeError &sipStrings_QtNetwork[7150]
#define sipNameNr_RemoteHostClosedError 7172
#define sipName_RemoteHostClosedError &sipStrings_QtNetwork[7172]
#define sipNameNr_QAbstractNetworkCache 7194
#define sipName_QAbstractNetworkCache &sipStrings_QtNetwork[7194]
#define sipNameNr_QNetworkCacheMetaData 7216
#define sipName_QNetworkCacheMetaData &sipStrings_QtNetwork[7216]
#define sipNameNr_7238 7238
#define sipName_7238 &sipStrings_QtNetwork[7238]
#define sipNameNr_7259 7259
#define sipName_7259 &sipStrings_QtNetwork[7259]
#define sipNameNr_addPendingConnection 7280
#define sipName_addPendingConnection &sipStrings_QtNetwork[7280]
#define sipNameNr_OcspMalformedRequest 7301
#define sipName_OcspMalformedRequest &sipStrings_QtNetwork[7301]
#define sipNameNr_CertificateUntrusted 7322
#define sipName_CertificateUntrusted &sipStrings_QtNetwork[7322]
#define sipNameNr_InvalidCaCertificate 7343
#define sipName_InvalidCaCertificate &sipStrings_QtNetwork[7343]
#define sipNameNr_InvalidNotAfterField 7364
#define sipName_InvalidNotAfterField &sipStrings_QtNetwork[7364]
#define sipNameNr_backendConfiguration 7385
#define sipName_backendConfiguration &sipStrings_QtNetwork[7385]
#define sipNameNr_systemCaCertificates 7406
#define sipName_systemCaCertificates &sipStrings_QtNetwork[7406]
#define sipNameNr_allowedNextProtocols 7427
#define sipName_allowedNextProtocols &sipStrings_QtNetwork[7427]
#define sipNameNr_peerCertificateChain 7448
#define sipName_peerCertificateChain &sipStrings_QtNetwork[7448]
#define sipNameNr_authenticationMethod 7469
#define sipName_authenticationMethod &sipStrings_QtNetwork[7469]
#define sipNameNr_issuerInfoAttributes 7490
#define sipName_issuerInfoAttributes &sipStrings_QtNetwork[7490]
#define sipNameNr_QSsl__EncodingFormat 7511
#define sipName_QSsl__EncodingFormat &sipStrings_QtNetwork[7511]
#define sipNameNr_CessationOfOperation 7532
#define sipName_CessationOfOperation &sipStrings_QtNetwork[7532]
#define sipNameNr_usagePoliciesChanged 7553
#define sipName_usagePoliciesChanged &sipStrings_QtNetwork[7553]
#define sipNameNr_ManualRedirectPolicy 7574
#define sipName_ManualRedirectPolicy &sipStrings_QtNetwork[7574]
#define sipNameNr_setOriginatingObject 7595
#define sipName_setOriginatingObject &sipStrings_QtNetwork[7595]
#define sipNameNr_Http2DirectAttribute 7616
#define sipName_Http2DirectAttribute &sipStrings_QtNetwork[7616]
#define sipNameNr_SpdyWasUsedAttribute 7637
#define sipName_SpdyWasUsedAttribute &sipStrings_QtNetwork[7637]
#define sipNameNr_SpdyAllowedAttribute 7658
#define sipName_SpdyAllowedAttribute &sipStrings_QtNetwork[7658]
#define sipNameNr_ContentConflictError 7679
#define sipName_ContentConflictError &sipStrings_QtNetwork[7679]
#define sipNameNr_ProtocolUnknownError 7700
#define sipName_ProtocolUnknownError &sipStrings_QtNetwork[7700]
#define sipNameNr_ContentNotFoundError 7721
#define sipName_ContentNotFoundError &sipStrings_QtNetwork[7721]
#define sipNameNr_QNetworkProxyFactory 7742
#define sipName_QNetworkProxyFactory &sipStrings_QtNetwork[7742]
#define sipNameNr_networkConfiguration 7763
#define sipName_networkConfiguration &sipStrings_QtNetwork[7763]
#define sipNameNr_clearAddressLifetime 7784
#define sipName_clearAddressLifetime &sipStrings_QtNetwork[7784]
#define sipNameNr_DnsEligibilityStatus 208
#define sipName_DnsEligibilityStatus &sipStrings_QtNetwork[208]
#define sipNameNr_QNetworkAddressEntry 7805
#define sipName_QNetworkAddressEntry &sipStrings_QtNetwork[7805]
#define sipNameNr_configurationChanged 7826
#define sipName_configurationChanged &sipStrings_QtNetwork[7826]
#define sipNameNr_configurationRemoved 7847
#define sipName_configurationRemoved &sipStrings_QtNetwork[7847]
#define sipNameNr_updateConfigurations 7868
#define sipName_updateConfigurations &sipStrings_QtNetwork[7868]
#define sipNameNr_defaultConfiguration 7889
#define sipName_defaultConfiguration &sipStrings_QtNetwork[7889]
#define sipNameNr_SystemSessionSupport 7910
#define sipName_SystemSessionSupport &sipStrings_QtNetwork[7910]
#define sipNameNr_setAutoDeleteReplies 7931
#define sipName_setAutoDeleteReplies &sipStrings_QtNetwork[7931]
#define sipNameNr_clearConnectionCache 7952
#define sipName_clearConnectionCache &sipStrings_QtNetwork[7952]
#define sipNameNr_setNetworkAccessible 7973
#define sipName_setNetworkAccessible &sipStrings_QtNetwork[7973]
#define sipNameNr_UnknownAccessibility 7994
#define sipName_UnknownAccessibility &sipStrings_QtNetwork[7994]
#define sipNameNr_NetworkAccessibility 122
#define sipName_NetworkAccessibility &sipStrings_QtNetwork[122]
#define sipNameNr_disconnectFromServer 8015
#define sipName_disconnectFromServer &sipStrings_QtNetwork[8015]
#define sipNameNr_waitForNewConnection 8036
#define sipName_waitForNewConnection &sipStrings_QtNetwork[8036]
#define sipNameNr_setServerPushEnabled 8057
#define sipName_setServerPushEnabled &sipStrings_QtNetwork[8057]
#define sipNameNr_isUniqueLocalUnicast 8078
#define sipName_isUniqueLocalUnicast &sipStrings_QtNetwork[8078]
#define sipNameNr_canonicalNameRecords 8099
#define sipName_canonicalNameRecords &sipStrings_QtNetwork[8099]
#define sipNameNr_QDnsDomainNameRecord 8120
#define sipName_QDnsDomainNameRecord &sipStrings_QtNetwork[8120]
#define sipNameNr_NetworkLayerProtocol 486
#define sipName_NetworkLayerProtocol &sipStrings_QtNetwork[486]
#define sipNameNr_8141 8141
#define sipName_8141 &sipStrings_QtNetwork[8141]
#define sipNameNr_leaveMulticastGroup 8161
#define sipName_leaveMulticastGroup &sipStrings_QtNetwork[8161]
#define sipNameNr_pendingDatagramSize 8181
#define sipName_pendingDatagramSize &sipStrings_QtNetwork[8181]
#define sipNameNr_hasPendingDatagrams 8201
#define sipName_hasPendingDatagrams &sipStrings_QtNetwork[8201]
#define sipNameNr_QSslSocket__SslMode 8221
#define sipName_QSslSocket__SslMode &sipStrings_QtNetwork[8221]
#define sipNameNr_OcspResponseExpired 8241
#define sipName_OcspResponseExpired &sipStrings_QtNetwork[8241]
#define sipNameNr_OcspNoResponseFound 8261
#define sipName_OcspNoResponseFound &sipStrings_QtNetwork[8261]
#define sipNameNr_CertificateRejected 8281
#define sipName_CertificateRejected &sipStrings_QtNetwork[8281]
#define sipNameNr_QSslError__SslError 8301
#define sipName_QSslError__SslError &sipStrings_QtNetwork[8301]
#define sipNameNr_ocspStaplingEnabled 8321
#define sipName_ocspStaplingEnabled &sipStrings_QtNetwork[8321]
#define sipNameNr_NextProtocolHttp1_1 8341
#define sipName_NextProtocolHttp1_1 &sipStrings_QtNetwork[8341]
#define sipNameNr_NextProtocolSpdy3_0 8361
#define sipName_NextProtocolSpdy3_0 &sipStrings_QtNetwork[8361]
#define sipNameNr_setLocalCertificate 8381
#define sipName_setLocalCertificate &sipStrings_QtNetwork[8381]
#define sipNameNr_StateOrProvinceName 8401
#define sipName_StateOrProvinceName &sipStrings_QtNetwork[8401]
#define sipNameNr_SessionAbortedError 8421
#define sipName_SessionAbortedError &sipStrings_QtNetwork[8421]
#define sipNameNr_UnknownSessionError 8441
#define sipName_UnknownSessionError &sipStrings_QtNetwork[8441]
#define sipNameNr_CustomVerbAttribute 8461
#define sipName_CustomVerbAttribute &sipStrings_QtNetwork[8461]
#define sipNameNr_ContentLengthHeader 8481
#define sipName_ContentLengthHeader &sipStrings_QtNetwork[8481]
#define sipNameNr_setSslConfiguration 8501
#define sipName_setSslConfiguration &sipStrings_QtNetwork[8501]
#define sipNameNr_InternalServerError 8521
#define sipName_InternalServerError &sipStrings_QtNetwork[8521]
#define sipNameNr_UnknownContentError 8541
#define sipName_UnknownContentError &sipStrings_QtNetwork[8541]
#define sipNameNr_ContentAccessDenied 8561
#define sipName_ContentAccessDenied &sipStrings_QtNetwork[8561]
#define sipNameNr_UnknownNetworkError 8581
#define sipName_UnknownNetworkError &sipStrings_QtNetwork[8581]
#define sipNameNr_systemProxyForQuery 8601
#define sipName_systemProxyForQuery &sipStrings_QtNetwork[8601]
#define sipNameNr_ListeningCapability 5660
#define sipName_ListeningCapability &sipStrings_QtNetwork[5660]
#define sipNameNr_TunnelingCapability 5684
#define sipName_TunnelingCapability &sipStrings_QtNetwork[5684]
#define sipNameNr_setApplicationProxy 8621
#define sipName_setApplicationProxy &sipStrings_QtNetwork[8621]
#define sipNameNr_setMaximumCacheSize 8641
#define sipName_setMaximumCacheSize &sipStrings_QtNetwork[8641]
#define sipNameNr_InternetAccessPoint 8661
#define sipName_InternetAccessPoint &sipStrings_QtNetwork[8661]
#define sipNameNr_activeConfiguration 8681
#define sipName_activeConfiguration &sipStrings_QtNetwork[8681]
#define sipNameNr_ServerNotFoundError 8701
#define sipName_ServerNotFoundError &sipStrings_QtNetwork[8701]
#define sipNameNr_QHttp2Configuration 8721
#define sipName_QHttp2Configuration &sipStrings_QtNetwork[8721]
#define sipNameNr_mailExchangeRecords 8741
#define sipName_mailExchangeRecords &sipStrings_QtNetwork[8741]
#define sipNameNr_InvalidRequestError 8761
#define sipName_InvalidRequestError &sipStrings_QtNetwork[8761]
#define sipNameNr_PathMtuSocketOption 8781
#define sipName_PathMtuSocketOption &sipStrings_QtNetwork[8781]
#define sipNameNr_TypeOfServiceOption 8801
#define sipName_TypeOfServiceOption &sipStrings_QtNetwork[8801]
#define sipNameNr_waitForDisconnected 8821
#define sipName_waitForDisconnected &sipStrings_QtNetwork[8821]
#define sipNameNr_setSocketDescriptor 8841
#define sipName_setSocketDescriptor &sipStrings_QtNetwork[8841]
#define sipNameNr_SocketResourceError 8861
#define sipName_SocketResourceError &sipStrings_QtNetwork[8861]
#define sipNameNr_waitForBytesWritten 8881
#define sipName_waitForBytesWritten &sipStrings_QtNetwork[8881]
#define sipNameNr_multicastInterface 8901
#define sipName_multicastInterface &sipStrings_QtNetwork[8901]
#define sipNameNr_joinMulticastGroup 8920
#define sipName_joinMulticastGroup &sipStrings_QtNetwork[8920]
#define sipNameNr_sslHandshakeErrors 8939
#define sipName_sslHandshakeErrors &sipStrings_QtNetwork[8939]
#define sipNameNr_PathLengthExceeded 8958
#define sipName_PathLengthExceeded &sipStrings_QtNetwork[8958]
#define sipNameNr_CertificateRevoked 8977
#define sipName_CertificateRevoked &sipStrings_QtNetwork[8977]
#define sipNameNr_CertificateExpired 8996
#define sipName_CertificateExpired &sipStrings_QtNetwork[8996]
#define sipNameNr_ephemeralServerKey 9015
#define sipName_ephemeralServerKey &sipStrings_QtNetwork[9015]
#define sipNameNr_setPeerVerifyDepth 9034
#define sipName_setPeerVerifyDepth &sipStrings_QtNetwork[9034]
#define sipNameNr_subjectDisplayName 9053
#define sipName_subjectDisplayName &sipStrings_QtNetwork[9053]
#define sipNameNr_QSsl__KeyAlgorithm 9072
#define sipName_QSsl__KeyAlgorithm &sipStrings_QtNetwork[9072]
#define sipNameNr_AffiliationChanged 9091
#define sipName_AffiliationChanged &sipStrings_QtNetwork[9091]
#define sipNameNr_setSessionProperty 9110
#define sipName_setSessionProperty &sipStrings_QtNetwork[9110]
#define sipNameNr_http2Configuration 9129
#define sipName_http2Configuration &sipStrings_QtNetwork[9129]
#define sipNameNr_LastModifiedHeader 9148
#define sipName_LastModifiedHeader &sipStrings_QtNetwork[9148]
#define sipNameNr_UnknownServerError 9167
#define sipName_UnknownServerError &sipStrings_QtNetwork[9167]
#define sipNameNr_ContentReSendError 9186
#define sipName_ContentReSendError &sipStrings_QtNetwork[9186]
#define sipNameNr_QNetworkProxyQuery 9205
#define sipName_QNetworkProxyQuery &sipStrings_QtNetwork[9205]
#define sipNameNr_isTransparentProxy 9224
#define sipName_isTransparentProxy &sipStrings_QtNetwork[9224]
#define sipNameNr_interfaceFromIndex 9243
#define sipName_interfaceFromIndex &sipStrings_QtNetwork[9243]
#define sipNameNr_setAddressLifetime 9262
#define sipName_setAddressLifetime &sipStrings_QtNetwork[9262]
#define sipNameNr_destinationAddress 9281
#define sipName_destinationAddress &sipStrings_QtNetwork[9281]
#define sipNameNr_isRoamingAvailable 9300
#define sipName_isRoamingAvailable &sipStrings_QtNetwork[9300]
#define sipNameNr_onlineStateChanged 9319
#define sipName_onlineStateChanged &sipStrings_QtNetwork[9319]
#define sipNameNr_configurationAdded 9338
#define sipName_configurationAdded &sipStrings_QtNetwork[9338]
#define sipNameNr_setTransferTimeout 9357
#define sipName_setTransferTimeout &sipStrings_QtNetwork[9357]
#define sipNameNr_incomingConnection 9376
#define sipName_incomingConnection &sipStrings_QtNetwork[9376]
#define sipNameNr_includesSubDomains 9395
#define sipName_includesSubDomains &sipStrings_QtNetwork[9395]
#define sipNameNr_TolerantConversion 9414
#define sipName_TolerantConversion &sipStrings_QtNetwork[9414]
#define sipNameNr_ConversionModeFlag 1415
#define sipName_ConversionModeFlag &sipStrings_QtNetwork[1415]
#define sipNameNr_hostAddressRecords 9433
#define sipName_hostAddressRecords &sipStrings_QtNetwork[9433]
#define sipNameNr_ServerRefusedError 9452
#define sipName_ServerRefusedError &sipStrings_QtNetwork[9452]
#define sipNameNr_ServerFailureError 9471
#define sipName_ServerFailureError &sipStrings_QtNetwork[9471]
#define sipNameNr_DefaultForPlatform 9490
#define sipName_DefaultForPlatform &sipStrings_QtNetwork[9490]
#define sipNameNr_MulticastTtlOption 9509
#define sipName_MulticastTtlOption &sipStrings_QtNetwork[9509]
#define sipNameNr_disconnectFromHost 9528
#define sipName_disconnectFromHost &sipStrings_QtNetwork[9528]
#define sipNameNr_UnknownSocketError 9547
#define sipName_UnknownSocketError &sipStrings_QtNetwork[9547]
#define sipNameNr_ProxyProtocolError 9566
#define sipName_ProxyProtocolError &sipStrings_QtNetwork[9566]
#define sipNameNr_ProxyNotFoundError 9585
#define sipName_ProxyNotFoundError &sipStrings_QtNetwork[9585]
#define sipNameNr_SocketTimeoutError 9604
#define sipName_SocketTimeoutError &sipStrings_QtNetwork[9604]
#define sipNameNr_9623 9623
#define sipName_9623 &sipStrings_QtNetwork[9623]
#define sipNameNr_setDefaultCiphers 9641
#define sipName_setDefaultCiphers &sipStrings_QtNetwork[9641]
#define sipNameNr_OcspStatusUnknown 9659
#define sipName_OcspStatusUnknown &sipStrings_QtNetwork[9659]
#define sipNameNr_OcspInternalError 9677
#define sipName_OcspInternalError &sipStrings_QtNetwork[9677]
#define sipNameNr_NoPeerCertificate 9695
#define sipName_NoPeerCertificate &sipStrings_QtNetwork[9695]
#define sipNameNr_QSslEllipticCurve 9713
#define sipName_QSslEllipticCurve &sipStrings_QtNetwork[9713]
#define sipNameNr_defaultParameters 9731
#define sipName_defaultParameters &sipStrings_QtNetwork[9731]
#define sipNameNr_addCaCertificates 9749
#define sipName_addCaCertificates &sipStrings_QtNetwork[9749]
#define sipNameNr_setEllipticCurves 9767
#define sipName_setEllipticCurves &sipStrings_QtNetwork[9767]
#define sipNameNr_setCaCertificates 9785
#define sipName_setCaCertificates &sipStrings_QtNetwork[9785]
#define sipNameNr_setPeerVerifyMode 9803
#define sipName_setPeerVerifyMode &sipStrings_QtNetwork[9803]
#define sipNameNr_QSslConfiguration 9821
#define sipName_QSslConfiguration &sipStrings_QtNetwork[9821]
#define sipNameNr_keyExchangeMethod 9839
#define sipName_keyExchangeMethod &sipStrings_QtNetwork[9839]
#define sipNameNr_issuerDisplayName 9857
#define sipName_issuerDisplayName &sipStrings_QtNetwork[9857]
#define sipNameNr_QSsl__SslProtocol 9875
#define sipName_QSsl__SslProtocol &sipStrings_QtNetwork[9875]
#define sipNameNr_QPasswordDigestor 9893
#define sipName_QPasswordDigestor &sipStrings_QtNetwork[9893]
#define sipNameNr_certificateStatus 9911
#define sipName_certificateStatus &sipStrings_QtNetwork[9911]
#define sipNameNr_setPeerVerifyName 9929
#define sipName_setPeerVerifyName &sipStrings_QtNetwork[9929]
#define sipNameNr_originatingObject 9947
#define sipName_originatingObject &sipStrings_QtNetwork[9947]
#define sipNameNr_IfNoneMatchHeader 9965
#define sipName_IfNoneMatchHeader &sipStrings_QtNetwork[9965]
#define sipNameNr_ContentTypeHeader 9983
#define sipName_ContentTypeHeader &sipStrings_QtNetwork[9983]
#define sipNameNr_UnknownProxyError 10001
#define sipName_UnknownProxyError &sipStrings_QtNetwork[10001]
#define sipNameNr_ProxyTimeoutError 10019
#define sipName_ProxyTimeoutError &sipStrings_QtNetwork[10019]
#define sipNameNr_CachingCapability 10037
#define sipName_CachingCapability &sipStrings_QtNetwork[10037]
#define sipNameNr_humanReadableName 10055
#define sipName_humanReadableName &sipStrings_QtNetwork[10055]
#define sipNameNr_interfaceFromName 10073
#define sipName_interfaceFromName &sipStrings_QtNetwork[10073]
#define sipNameNr_QNetworkInterface 10091
#define sipName_QNetworkInterface &sipStrings_QtNetwork[10091]
#define sipNameNr_preferredLifetime 10109
#define sipName_preferredLifetime &sipStrings_QtNetwork[10109]
#define sipNameNr_setDnsEligibility 10127
#define sipName_setDnsEligibility &sipStrings_QtNetwork[10127]
#define sipNameNr_setCacheDirectory 10145
#define sipName_setCacheDirectory &sipStrings_QtNetwork[10145]
#define sipNameNr_QNetworkDiskCache 10163
#define sipName_QNetworkDiskCache &sipStrings_QtNetwork[10163]
#define sipNameNr_setInterfaceIndex 10181
#define sipName_setInterfaceIndex &sipStrings_QtNetwork[10181]
#define sipNameNr_setCookiesFromUrl 10199
#define sipName_setCookiesFromUrl &sipStrings_QtNetwork[10199]
#define sipNameNr_QNetworkCookieJar 10217
#define sipName_QNetworkCookieJar &sipStrings_QtNetwork[10217]
#define sipNameNr_hasSameIdentifier 10235
#define sipName_hasSameIdentifier &sipStrings_QtNetwork[10235]
#define sipNameNr_setConnectTimeout 10253
#define sipName_setConnectTimeout &sipStrings_QtNetwork[10253]
#define sipNameNr_allConfigurations 10271
#define sipName_allConfigurations &sipStrings_QtNetwork[10271]
#define sipNameNr_autoDeleteReplies 10289
#define sipName_autoDeleteReplies &sipStrings_QtNetwork[10289]
#define sipNameNr_setRedirectPolicy 10307
#define sipName_setRedirectPolicy &sipStrings_QtNetwork[10307]
#define sipNameNr_networkAccessible 10325
#define sipName_networkAccessible &sipStrings_QtNetwork[10325]
#define sipNameNr_sendCustomRequest 10343
#define sipName_sendCustomRequest &sipStrings_QtNetwork[10343]
#define sipNameNr_WorldAccessOption 10361
#define sipName_WorldAccessOption &sipStrings_QtNetwork[10361]
#define sipNameNr_OtherAccessOption 10379
#define sipName_OtherAccessOption &sipStrings_QtNetwork[10379]
#define sipNameNr_GroupAccessOption 10397
#define sipName_GroupAccessOption &sipStrings_QtNetwork[10397]
#define sipNameNr_serverPushEnabled 10415
#define sipName_serverPushEnabled &sipStrings_QtNetwork[10415]
#define sipNameNr_IncludeSubDomains 10433
#define sipName_IncludeSubDomains &sipStrings_QtNetwork[10433]
#define sipNameNr_nameserverChanged 10451
#define sipName_nameserverChanged &sipStrings_QtNetwork[10451]
#define sipNameNr_nameServerRecords 10469
#define sipName_nameServerRecords &sipStrings_QtNetwork[10469]
#define sipNameNr_InvalidReplyError 10487
#define sipName_InvalidReplyError &sipStrings_QtNetwork[10487]
#define sipNameNr_QDnsLookup__Error 10505
#define sipName_QDnsLookup__Error &sipStrings_QtNetwork[10505]
#define sipNameNr_QDnsServiceRecord 10523
#define sipName_QDnsServiceRecord &sipStrings_QtNetwork[10523]
#define sipNameNr_setReadBufferSize 10541
#define sipName_setReadBufferSize &sipStrings_QtNetwork[10541]
#define sipNameNr_AddressInUseError 10559
#define sipName_AddressInUseError &sipStrings_QtNetwork[10559]
#define sipNameNr_SocketAccessError 10577
#define sipName_SocketAccessError &sipStrings_QtNetwork[10577]
#define sipNameNr_HostNotFoundError 10595
#define sipName_HostNotFoundError &sipStrings_QtNetwork[10595]
#define sipNameNr_UnknownSocketType 10613
#define sipName_UnknownSocketType &sipStrings_QtNetwork[10613]
#define sipNameNr_setExpirationDate 10631
#define sipName_setExpirationDate &sipStrings_QtNetwork[10631]
#define sipNameNr_RegularExpression 10649
#define sipName_RegularExpression &sipStrings_QtNetwork[10649]
#define sipNameNr_sip_simplewrapper 10667
#define sipName_sip_simplewrapper &sipStrings_QtNetwork[10667]
#define sipNameNr_10685 10685
#define sipName_10685 &sipStrings_QtNetwork[10685]
#define sipNameNr_waitForEncrypted 10702
#define sipName_waitForEncrypted &sipStrings_QtNetwork[10702]
#define sipNameNr_OcspUnauthorized 10719
#define sipName_OcspUnauthorized &sipStrings_QtNetwork[10719]
#define sipNameNr_HostNameMismatch 10736
#define sipName_HostNameMismatch &sipStrings_QtNetwork[10736]
#define sipNameNr_addCaCertificate 10753
#define sipName_addCaCertificate &sipStrings_QtNetwork[10753]
#define sipNameNr_supportedCiphers 10770
#define sipName_supportedCiphers &sipStrings_QtNetwork[10770]
#define sipNameNr_setSessionTicket 10787
#define sipName_setSessionTicket &sipStrings_QtNetwork[10787]
#define sipNameNr_localCertificate 10804
#define sipName_localCertificate &sipStrings_QtNetwork[10804]
#define sipNameNr_encryptionMethod 10821
#define sipName_encryptionMethod &sipStrings_QtNetwork[10821]
#define sipNameNr_QSsl__SslOptions 10838
#define sipName_QSsl__SslOptions &sipStrings_QtNetwork[10838]
#define sipNameNr_revocationReason 10855
#define sipName_revocationReason &sipStrings_QtNetwork[10855]
#define sipNameNr_CacheLoadControl 949
#define sipName_CacheLoadControl &sipStrings_QtNetwork[949]
#define sipNameNr_downloadProgress 10872
#define sipName_downloadProgress &sipStrings_QtNetwork[10872]
#define sipNameNr_ContentGoneError 10889
#define sipName_ContentGoneError &sipStrings_QtNetwork[10889]
#define sipNameNr_applicationProxy 10906
#define sipName_applicationProxy &sipStrings_QtNetwork[10906]
#define sipNameNr_HttpCachingProxy 10923
#define sipName_HttpCachingProxy &sipStrings_QtNetwork[10923]
#define sipNameNr_validityLifetime 10940
#define sipName_validityLifetime &sipStrings_QtNetwork[10940]
#define sipNameNr_maximumCacheSize 10957
#define sipName_maximumCacheSize &sipStrings_QtNetwork[10957]
#define sipNameNr_QNetworkDatagram 10974
#define sipName_QNetworkDatagram &sipStrings_QtNetwork[10974]
#define sipNameNr_NameAndValueOnly 10991
#define sipName_NameAndValueOnly &sipStrings_QtNetwork[10991]
#define sipNameNr_bearerTypeFamily 11008
#define sipName_bearerTypeFamily &sipStrings_QtNetwork[11008]
#define sipNameNr_sslConfiguration 11025
#define sipName_sslConfiguration &sipStrings_QtNetwork[11025]
#define sipNameNr_supportedSchemes 11042
#define sipName_supportedSchemes &sipStrings_QtNetwork[11042]
#define sipNameNr_clearAccessCache 11059
#define sipName_clearAccessCache &sipStrings_QtNetwork[11059]
#define sipNameNr_setConfiguration 11076
#define sipName_setConfiguration &sipStrings_QtNetwork[11076]
#define sipNameNr_LocalSocketState 2074
#define sipName_LocalSocketState &sipStrings_QtNetwork[2074]
#define sipNameNr_LocalSocketError 2105
#define sipName_LocalSocketError &sipStrings_QtNetwork[2105]
#define sipNameNr_setSocketOptions 11093
#define sipName_setSocketOptions &sipStrings_QtNetwork[11093]
#define sipNameNr_UserAccessOption 11110
#define sipName_UserAccessOption &sipStrings_QtNetwork[11110]
#define sipNameNr_StrictConversion 11127
#define sipName_StrictConversion &sipStrings_QtNetwork[11127]
#define sipNameNr_ConvertLocalHost 11144
#define sipName_ConvertLocalHost &sipStrings_QtNetwork[11144]
#define sipNameNr_QDnsLookup__Type 11161
#define sipName_QDnsLookup__Type &sipStrings_QtNetwork[11161]
#define sipNameNr_PauseOnSslErrors 11178
#define sipName_PauseOnSslErrors &sipStrings_QtNetwork[11178]
#define sipNameNr_ReuseAddressHint 11195
#define sipName_ReuseAddressHint &sipStrings_QtNetwork[11195]
#define sipNameNr_DontShareAddress 11212
#define sipName_DontShareAddress &sipStrings_QtNetwork[11212]
#define sipNameNr_waitForConnected 11229
#define sipName_waitForConnected &sipStrings_QtNetwork[11229]
#define sipNameNr_socketDescriptor 11246
#define sipName_socketDescriptor &sipStrings_QtNetwork[11246]
#define sipNameNr_UnconnectedState 11263
#define sipName_UnconnectedState &sipStrings_QtNetwork[11263]
#define sipNameNr_SslInternalError 11280
#define sipName_SslInternalError &sipStrings_QtNetwork[11280]
#define sipNameNr_waitForReadyRead 11297
#define sipName_waitForReadyRead &sipStrings_QtNetwork[11297]
#define sipNameNr_UnspecifiedError 11314
#define sipName_UnspecifiedError &sipStrings_QtNetwork[11314]
#define sipNameNr_disconnectNotify 11331
#define sipName_disconnectNotify &sipStrings_QtNetwork[11331]
#define sipNameNr_receiveDatagram 11348
#define sipName_receiveDatagram &sipStrings_QtNetwork[11348]
#define sipNameNr_resumeAccepting 11364
#define sipName_resumeAccepting &sipStrings_QtNetwork[11364]
#define sipNameNr_peerVerifyError 11380
#define sipName_peerVerifyError &sipStrings_QtNetwork[11380]
#define sipNameNr_UnencryptedMode 11396
#define sipName_UnencryptedMode &sipStrings_QtNetwork[11396]
#define sipNameNr_setPreSharedKey 11412
#define sipName_setPreSharedKey &sipStrings_QtNetwork[11412]
#define sipNameNr_isTlsNamedCurve 11428
#define sipName_isTlsNamedCurve &sipStrings_QtNetwork[11428]
#define sipNameNr_sessionProtocol 11444
#define sipName_sessionProtocol &sipStrings_QtNetwork[11444]
#define sipNameNr_peerCertificate 11460
#define sipName_peerCertificate &sipStrings_QtNetwork[11460]
#define sipNameNr_peerVerifyDepth 11476
#define sipName_peerVerifyDepth &sipStrings_QtNetwork[11476]
#define sipNameNr_QSslCertificate 11492
#define sipName_QSslCertificate &sipStrings_QtNetwork[11492]
#define sipNameNr_QSsl__SslOption 11508
#define sipName_QSsl__SslOption &sipStrings_QtNetwork[11508]
#define sipNameNr_DtlsV1_2OrLater 11524
#define sipName_DtlsV1_2OrLater &sipStrings_QtNetwork[11524]
#define sipNameNr_DtlsV1_0OrLater 11540
#define sipName_DtlsV1_0OrLater &sipStrings_QtNetwork[11540]
#define sipNameNr_SecureProtocols 11556
#define sipName_SecureProtocols &sipStrings_QtNetwork[11556]
#define sipNameNr_UnknownProtocol 11572
#define sipName_UnknownProtocol &sipStrings_QtNetwork[11572]
#define sipNameNr_deriveKeyPbkdf2 11588
#define sipName_deriveKeyPbkdf2 &sipStrings_QtNetwork[11588]
#define sipNameNr_deriveKeyPbkdf1 11604
#define sipName_deriveKeyPbkdf1 &sipStrings_QtNetwork[11604]
#define sipNameNr_CertificateHold 11620
#define sipName_CertificateHold &sipStrings_QtNetwork[11620]
#define sipNameNr_sessionProperty 11636
#define sipName_sessionProperty &sipStrings_QtNetwork[11636]
#define sipNameNr_QNetworkSession 11652
#define sipName_QNetworkSession &sipStrings_QtNetwork[11652]
#define sipNameNr_UserAgentHeader 11668
#define sipName_UserAgentHeader &sipStrings_QtNetwork[11668]
#define sipNameNr_SetCookieHeader 11684
#define sipName_SetCookieHeader &sipStrings_QtNetwork[11684]
#define sipNameNr_QNetworkRequest 11700
#define sipName_QNetworkRequest &sipStrings_QtNetwork[11700]
#define sipNameNr_redirectAllowed 11716
#define sipName_redirectAllowed &sipStrings_QtNetwork[11716]
#define sipNameNr_metaDataChanged 11732
#define sipName_metaDataChanged &sipStrings_QtNetwork[11732]
#define sipNameNr_ignoreSslErrors 11748
#define sipName_ignoreSslErrors &sipStrings_QtNetwork[11748]
#define sipNameNr_ProtocolFailure 11764
#define sipName_ProtocolFailure &sipStrings_QtNetwork[11764]
#define sipNameNr_setPeerHostName 11780
#define sipName_setPeerHostName &sipStrings_QtNetwork[11780]
#define sipNameNr_setCapabilities 11796
#define sipName_setCapabilities &sipStrings_QtNetwork[11796]
#define sipNameNr_FtpCachingProxy 11812
#define sipName_FtpCachingProxy &sipStrings_QtNetwork[11812]
#define sipNameNr_hardwareAddress 11828
#define sipName_hardwareAddress &sipStrings_QtNetwork[11828]
#define sipNameNr_isLifetimeKnown 11844
#define sipName_isLifetimeKnown &sipStrings_QtNetwork[11844]
#define sipNameNr_setPrefixLength 11860
#define sipName_setPrefixLength &sipStrings_QtNetwork[11860]
#define sipNameNr_destinationPort 11876
#define sipName_destinationPort &sipStrings_QtNetwork[11876]
#define sipNameNr_isSessionCookie 11892
#define sipName_isSessionCookie &sipStrings_QtNetwork[11892]
#define sipNameNr_BearerBluetooth 11908
#define sipName_BearerBluetooth &sipStrings_QtNetwork[11908]
#define sipNameNr_updateCompleted 11924
#define sipName_updateCompleted &sipStrings_QtNetwork[11924]
#define sipNameNr_transferTimeout 11940
#define sipName_transferTimeout &sipStrings_QtNetwork[11940]
#define sipNameNr_setProxyFactory 11956
#define sipName_setProxyFactory &sipStrings_QtNetwork[11956]
#define sipNameNr_CustomOperation 11972
#define sipName_CustomOperation &sipStrings_QtNetwork[11972]
#define sipNameNr_DeleteOperation 11988
#define sipName_DeleteOperation &sipStrings_QtNetwork[11988]
#define sipNameNr_connectToServer 12004
#define sipName_connectToServer &sipStrings_QtNetwork[12004]
#define sipNameNr_ConnectionError 12020
#define sipName_ConnectionError &sipStrings_QtNetwork[12020]
#define sipNameNr_PeerClosedError 12036
#define sipName_PeerClosedError &sipStrings_QtNetwork[12036]
#define sipNameNr_AlternativeType 12052
#define sipName_AlternativeType &sipStrings_QtNetwork[12052]
#define sipNameNr_setMaxFrameSize 12068
#define sipName_setMaxFrameSize &sipStrings_QtNetwork[12068]
#define sipNameNr_localDomainName 12084
#define sipName_localDomainName &sipStrings_QtNetwork[12084]
#define sipNameNr_abortHostLookup 12100
#define sipName_abortHostLookup &sipStrings_QtNetwork[12100]
#define sipNameNr_setSocketOption 12116
#define sipName_setSocketOption &sipStrings_QtNetwork[12116]
#define sipNameNr_KeepAliveOption 12132
#define sipName_KeepAliveOption &sipStrings_QtNetwork[12132]
#define sipNameNr_setLocalAddress 12148
#define sipName_setLocalAddress &sipStrings_QtNetwork[12148]
#define sipNameNr_ConnectingState 12164
#define sipName_ConnectingState &sipStrings_QtNetwork[12164]
#define sipNameNr_HostLookupState 12180
#define sipName_HostLookupState &sipStrings_QtNetwork[12180]
#define sipNameNr_QAbstractSocket 12196
#define sipName_QAbstractSocket &sipStrings_QtNetwork[12196]
#define sipNameNr_setLastModified 12212
#define sipName_setLastModified &sipStrings_QtNetwork[12212]
#define sipNameNr_PyQt5_QtNetwork 12228
#define sipName_PyQt5_QtNetwork &sipStrings_QtNetwork[12228]
#define sipNameNr_pauseAccepting 12244
#define sipName_pauseAccepting &sipStrings_QtNetwork[12244]
#define sipNameNr_AutoVerifyPeer 12259
#define sipName_AutoVerifyPeer &sipStrings_QtNetwork[12259]
#define sipNameNr_PeerVerifyMode 3753
#define sipName_PeerVerifyMode &sipStrings_QtNetwork[3753]
#define sipNameNr_defaultCiphers 12274
#define sipName_defaultCiphers &sipStrings_QtNetwork[12274]
#define sipNameNr_OcspSigRequred 12289
#define sipName_OcspSigRequred &sipStrings_QtNetwork[12289]
#define sipNameNr_InvalidPurpose 12304
#define sipName_InvalidPurpose &sipStrings_QtNetwork[12304]
#define sipNameNr_ellipticCurves 12319
#define sipName_ellipticCurves &sipStrings_QtNetwork[12319]
#define sipNameNr_peerVerifyMode 12334
#define sipName_peerVerifyMode &sipStrings_QtNetwork[12334]
#define sipNameNr_protocolString 12349
#define sipName_protocolString &sipStrings_QtNetwork[12349]
#define sipNameNr_caCertificates 12364
#define sipName_caCertificates &sipStrings_QtNetwork[12364]
#define sipNameNr_TlsV1_3OrLater 12379
#define sipName_TlsV1_3OrLater &sipStrings_QtNetwork[12379]
#define sipNameNr_TlsV1_2OrLater 12394
#define sipName_TlsV1_2OrLater &sipStrings_QtNetwork[12394]
#define sipNameNr_TlsV1_1OrLater 12409
#define sipName_TlsV1_1OrLater &sipStrings_QtNetwork[12409]
#define sipNameNr_TlsV1_0OrLater 12424
#define sipName_TlsV1_0OrLater &sipStrings_QtNetwork[12424]
#define sipNameNr_IpAddressEntry 12439
#define sipName_IpAddressEntry &sipStrings_QtNetwork[12439]
#define sipNameNr_EncodingFormat 7517
#define sipName_EncodingFormat &sipStrings_QtNetwork[7517]
#define sipNameNr_peerVerifyName 12454
#define sipName_peerVerifyName &sipStrings_QtNetwork[12454]
#define sipNameNr_RedirectPolicy 1516
#define sipName_RedirectPolicy &sipStrings_QtNetwork[1516]
#define sipNameNr_LocationHeader 12469
#define sipName_LocationHeader &sipStrings_QtNetwork[12469]
#define sipNameNr_rawHeaderPairs 12484
#define sipName_rawHeaderPairs &sipStrings_QtNetwork[12484]
#define sipNameNr_uploadProgress 12499
#define sipName_uploadProgress &sipStrings_QtNetwork[12499]
#define sipNameNr_isCachingProxy 12514
#define sipName_isCachingProxy &sipStrings_QtNetwork[12514]
#define sipNameNr_addressEntries 12529
#define sipName_addressEntries &sipStrings_QtNetwork[12529]
#define sipNameNr_InterfaceFlags 1053
#define sipName_InterfaceFlags &sipStrings_QtNetwork[1053]
#define sipNameNr_IsPointToPoint 12544
#define sipName_IsPointToPoint &sipStrings_QtNetwork[12544]
#define sipNameNr_dnsEligibility 12559
#define sipName_dnsEligibility &sipStrings_QtNetwork[12559]
#define sipNameNr_cacheDirectory 12574
#define sipName_cacheDirectory &sipStrings_QtNetwork[12574]
#define sipNameNr_setDestination 12589
#define sipName_setDestination &sipStrings_QtNetwork[12589]
#define sipNameNr_interfaceIndex 12604
#define sipName_interfaceIndex &sipStrings_QtNetwork[12604]
#define sipNameNr_validateCookie 12619
#define sipName_validateCookie &sipStrings_QtNetwork[12619]
#define sipNameNr_QNetworkCookie 12634
#define sipName_QNetworkCookie &sipStrings_QtNetwork[12634]
#define sipNameNr_connectTimeout 12649
#define sipName_connectTimeout &sipStrings_QtNetwork[12649]
#define sipNameNr_bearerTypeName 12664
#define sipName_bearerTypeName &sipStrings_QtNetwork[12664]
#define sipNameNr_BearerCDMA2000 12679
#define sipName_BearerCDMA2000 &sipStrings_QtNetwork[12679]
#define sipNameNr_BearerEthernet 12694
#define sipName_BearerEthernet &sipStrings_QtNetwork[12694]
#define sipNameNr_PrivatePurpose 12709
#define sipName_PrivatePurpose &sipStrings_QtNetwork[12709]
#define sipNameNr_UnknownPurpose 12724
#define sipName_UnknownPurpose &sipStrings_QtNetwork[12724]
#define sipNameNr_ServiceNetwork 12739
#define sipName_ServiceNetwork &sipStrings_QtNetwork[12739]
#define sipNameNr_DataStatistics 12754
#define sipName_DataStatistics &sipStrings_QtNetwork[12754]
#define sipNameNr_redirectPolicy 12769
#define sipName_redirectPolicy &sipStrings_QtNetwork[12769]
#define sipNameNr_deleteResource 12784
#define sipName_deleteResource &sipStrings_QtNetwork[12784]
#define sipNameNr_fullServerName 12799
#define sipName_fullServerName &sipStrings_QtNetwork[12799]
#define sipNameNr_setContentType 12814
#define sipName_setContentType &sipStrings_QtNetwork[12814]
#define sipNameNr_QHttpMultiPart 12829
#define sipName_QHttpMultiPart &sipStrings_QtNetwork[12829]
#define sipNameNr_ConversionMode 3052
#define sipName_ConversionMode &sipStrings_QtNetwork[3052]
#define sipNameNr_SpecialAddress 3081
#define sipName_SpecialAddress &sipStrings_QtNetwork[3081]
#define sipNameNr_serviceRecords 12844
#define sipName_serviceRecords &sipStrings_QtNetwork[12844]
#define sipNameNr_pointerRecords 12859
#define sipName_pointerRecords &sipStrings_QtNetwork[12859]
#define sipNameNr_QDnsTextRecord 12874
#define sipName_QDnsTextRecord &sipStrings_QtNetwork[12874]
#define sipNameNr_QAuthenticator 12889
#define sipName_QAuthenticator &sipStrings_QtNetwork[12889]
#define sipNameNr_setProtocolTag 12904
#define sipName_setProtocolTag &sipStrings_QtNetwork[12904]
#define sipNameNr_LowDelayOption 12919
#define sipName_LowDelayOption &sipStrings_QtNetwork[12919]
#define sipNameNr_setPeerAddress 12934
#define sipName_setPeerAddress &sipStrings_QtNetwork[12934]
#define sipNameNr_setSocketError 12949
#define sipName_setSocketError &sipStrings_QtNetwork[12949]
#define sipNameNr_setSocketState 12964
#define sipName_setSocketState &sipStrings_QtNetwork[12964]
#define sipNameNr_readBufferSize 12979
#define sipName_readBufferSize &sipStrings_QtNetwork[12979]
#define sipNameNr_ListeningState 12994
#define sipName_ListeningState &sipStrings_QtNetwork[12994]
#define sipNameNr_ConnectedState 13009
#define sipName_ConnectedState &sipStrings_QtNetwork[13009]
#define sipNameNr_TemporaryError 13024
#define sipName_TemporaryError &sipStrings_QtNetwork[13024]
#define sipNameNr_OperationError 1580
#define sipName_OperationError &sipStrings_QtNetwork[1580]
#define sipNameNr_updateMetaData 13039
#define sipName_updateMetaData &sipStrings_QtNetwork[13039]
#define sipNameNr_expirationDate 13054
#define sipName_expirationDate &sipStrings_QtNetwork[13054]
#define sipNameNr_NormalPriority 13069
#define sipName_NormalPriority &sipStrings_QtNetwork[13069]
#define sipNameNr_setErrorString 13084
#define sipName_setErrorString &sipStrings_QtNetwork[13084]
#define sipNameNr_bytesAvailable 13099
#define sipName_bytesAvailable &sipStrings_QtNetwork[13099]
#define sipNameNr_writeDatagram 13114
#define sipName_writeDatagram &sipStrings_QtNetwork[13114]
#define sipNameNr_serverAddress 13128
#define sipName_serverAddress &sipStrings_QtNetwork[13128]
#define sipNameNr_ocspResponses 13142
#define sipName_ocspResponses &sipStrings_QtNetwork[13142]
#define sipNameNr_SslServerMode 13156
#define sipName_SslServerMode &sipStrings_QtNetwork[13156]
#define sipNameNr_SslClientMode 13170
#define sipName_SslClientMode &sipStrings_QtNetwork[13170]
#define sipNameNr_fromShortName 13184
#define sipName_fromShortName &sipStrings_QtNetwork[13184]
#define sipNameNr_sessionTicket 13198
#define sipName_sessionTicket &sipStrings_QtNetwork[13198]
#define sipNameNr_testSslOption 13212
#define sipName_testSslOption &sipStrings_QtNetwork[13212]
#define sipNameNr_setPrivateKey 13226
#define sipName_setPrivateKey &sipStrings_QtNetwork[13226]
#define sipNameNr_sessionCipher 13240
#define sipName_sessionCipher &sipStrings_QtNetwork[13240]
#define sipNameNr_supportedBits 13254
#define sipName_supportedBits &sipStrings_QtNetwork[13254]
#define sipNameNr_isBlacklisted 13268
#define sipName_isBlacklisted &sipStrings_QtNetwork[13268]
#define sipNameNr_effectiveDate 13282
#define sipName_effectiveDate &sipStrings_QtNetwork[13282]
#define sipNameNr_QSsl__KeyType 13296
#define sipName_QSsl__KeyType &sipStrings_QtNetwork[13296]
#define sipNameNr_QOcspResponse 13310
#define sipName_QOcspResponse &sipStrings_QtNetwork[13310]
#define sipNameNr_RemoveFromCRL 13324
#define sipName_RemoveFromCRL &sipStrings_QtNetwork[13324]
#define sipNameNr_KeyCompromise 13338
#define sipName_KeyCompromise &sipStrings_QtNetwork[13338]
#define sipNameNr_usagePolicies 13352
#define sipName_usagePolicies &sipStrings_QtNetwork[13352]
#define sipNameNr_UsagePolicies 1798
#define sipName_UsagePolicies &sipStrings_QtNetwork[1798]
#define sipNameNr_waitForOpened 13366
#define sipName_waitForOpened &sipStrings_QtNetwork[13366]
#define sipNameNr_PreferNetwork 13380
#define sipName_PreferNetwork &sipStrings_QtNetwork[13380]
#define sipNameNr_AlwaysNetwork 13394
#define sipName_AlwaysNetwork &sipStrings_QtNetwork[13394]
#define sipNameNr_IfMatchHeader 13408
#define sipName_IfMatchHeader &sipStrings_QtNetwork[13408]
#define sipNameNr_bytesReceived 13422
#define sipName_bytesReceived &sipStrings_QtNetwork[13422]
#define sipNameNr_QNetworkReply 13436
#define sipName_QNetworkReply &sipStrings_QtNetwork[13436]
#define sipNameNr_proxyForQuery 13450
#define sipName_proxyForQuery &sipStrings_QtNetwork[13450]
#define sipNameNr_rawHeaderList 13464
#define sipName_rawHeaderList &sipStrings_QtNetwork[13464]
#define sipNameNr_QNetworkProxy 13478
#define sipName_QNetworkProxy &sipStrings_QtNetwork[13478]
#define sipNameNr_InterfaceType 1255
#define sipName_InterfaceType &sipStrings_QtNetwork[1255]
#define sipNameNr_allInterfaces 13492
#define sipName_allInterfaces &sipStrings_QtNetwork[13492]
#define sipNameNr_InterfaceFlag 1288
#define sipName_InterfaceFlag &sipStrings_QtNetwork[1288]
#define sipNameNr_DnsIneligible 13506
#define sipName_DnsIneligible &sipStrings_QtNetwork[13506]
#define sipNameNr_senderAddress 13520
#define sipName_senderAddress &sipStrings_QtNetwork[13520]
#define sipNameNr_setAllCookies 13534
#define sipName_setAllCookies &sipStrings_QtNetwork[13534]
#define sipNameNr_cookiesForUrl 13548
#define sipName_cookiesForUrl &sipStrings_QtNetwork[13548]
#define sipNameNr_BearerUnknown 13562
#define sipName_BearerUnknown &sipStrings_QtNetwork[13562]
#define sipNameNr_PublicPurpose 13576
#define sipName_PublicPurpose &sipStrings_QtNetwork[13576]
#define sipNameNr_ForcedRoaming 13590
#define sipName_ForcedRoaming &sipStrings_QtNetwork[13590]
#define sipNameNr_NotAccessible 13604
#define sipName_NotAccessible &sipStrings_QtNetwork[13604]
#define sipNameNr_createRequest 13618
#define sipName_createRequest &sipStrings_QtNetwork[13618]
#define sipNameNr_PostOperation 13632
#define sipName_PostOperation &sipStrings_QtNetwork[13632]
#define sipNameNr_HeadOperation 13646
#define sipName_HeadOperation &sipStrings_QtNetwork[13646]
#define sipNameNr_setServerName 13660
#define sipName_setServerName &sipStrings_QtNetwork[13660]
#define sipNameNr_socketOptions 13674
#define sipName_socketOptions &sipStrings_QtNetwork[13674]
#define sipNameNr_SocketOptions 3476
#define sipName_SocketOptions &sipStrings_QtNetwork[3476]
#define sipNameNr_newConnection 13688
#define sipName_newConnection &sipStrings_QtNetwork[13688]
#define sipNameNr_setBodyDevice 13702
#define sipName_setBodyDevice &sipStrings_QtNetwork[13702]
#define sipNameNr_localHostName 13716
#define sipName_localHostName &sipStrings_QtNetwork[13716]
#define sipNameNr_HostInfoError 5234
#define sipName_HostInfoError &sipStrings_QtNetwork[5234]
#define sipNameNr_toIPv6Address 13730
#define sipName_toIPv6Address &sipStrings_QtNetwork[13730]
#define sipNameNr_toIPv4Address 13744
#define sipName_toIPv4Address &sipStrings_QtNetwork[13744]
#define sipNameNr_LocalHostIPv6 13758
#define sipName_LocalHostIPv6 &sipStrings_QtNetwork[13758]
#define sipNameNr_setNameserver 13772
#define sipName_setNameserver &sipStrings_QtNetwork[13772]
#define sipNameNr_NotFoundError 7728
#define sipName_NotFoundError &sipStrings_QtNetwork[7728]
#define sipNameNr_ResolverError 13786
#define sipName_ResolverError &sipStrings_QtNetwork[13786]
#define sipNameNr_connectToHost 13800
#define sipName_connectToHost &sipStrings_QtNetwork[13800]
#define sipNameNr_AnyIPProtocol 13814
#define sipName_AnyIPProtocol &sipStrings_QtNetwork[13814]
#define sipNameNr_setAttributes 13828
#define sipName_setAttributes &sipStrings_QtNetwork[13828]
#define sipNameNr_setSaveToDisk 13842
#define sipName_setSaveToDisk &sipStrings_QtNetwork[13842]
#define sipNameNr_setRawHeaders 13856
#define sipName_setRawHeaders &sipStrings_QtNetwork[13856]
#define sipNameNr_configuration 13870
#define sipName_configuration &sipStrings_QtNetwork[13870]
#define sipNameNr_PatternSyntax 1643
#define sipName_PatternSyntax &sipStrings_QtNetwork[1643]
#define sipNameNr_errorOccurred 13884
#define sipName_errorOccurred &sipStrings_QtNetwork[13884]
#define sipNameNr_connectNotify 11334
#define sipName_connectNotify &sipStrings_QtNetwork[11334]
#define sipNameNr_readDatagram 13898
#define sipName_readDatagram &sipStrings_QtNetwork[13898]
#define sipNameNr_preSharedKey 13911
#define sipName_preSharedKey &sipStrings_QtNetwork[13911]
#define sipNameNr_identityHint 13924
#define sipName_identityHint &sipStrings_QtNetwork[13924]
#define sipNameNr_OcspTryLater 13937
#define sipName_OcspTryLater &sipStrings_QtNetwork[13937]
#define sipNameNr_NoSslSupport 13950
#define sipName_NoSslSupport &sipStrings_QtNetwork[13950]
#define sipNameNr_fromLongName 13963
#define sipName_fromLongName &sipStrings_QtNetwork[13963]
#define sipNameNr_setSslOption 13976
#define sipName_setSslOption &sipStrings_QtNetwork[13976]
#define sipNameNr_importPkcs12 13989
#define sipName_importPkcs12 &sipStrings_QtNetwork[13989]
#define sipNameNr_isSelfSigned 14002
#define sipName_isSelfSigned &sipStrings_QtNetwork[14002]
#define sipNameNr_serialNumber 14015
#define sipName_serialNumber &sipStrings_QtNetwork[14015]
#define sipNameNr_EmailAddress 14028
#define sipName_EmailAddress &sipStrings_QtNetwork[14028]
#define sipNameNr_SerialNumber 14041
#define sipName_SerialNumber &sipStrings_QtNetwork[14041]
#define sipNameNr_LocalityName 14054
#define sipName_LocalityName &sipStrings_QtNetwork[14054]
#define sipNameNr_Organization 14067
#define sipName_Organization &sipStrings_QtNetwork[14067]
#define sipNameNr_KeyAlgorithm 9078
#define sipName_KeyAlgorithm &sipStrings_QtNetwork[9078]
#define sipNameNr_CACompromise 14080
#define sipName_CACompromise &sipStrings_QtNetwork[14080]
#define sipNameNr_RoamingError 14093
#define sipName_RoamingError &sipStrings_QtNetwork[14093]
#define sipNameNr_SessionError 2381
#define sipName_SessionError &sipStrings_QtNetwork[2381]
#define sipNameNr_Disconnected 8828
#define sipName_Disconnected &sipStrings_QtNetwork[8828]
#define sipNameNr_NotAvailable 14106
#define sipName_NotAvailable &sipStrings_QtNetwork[14106]
#define sipNameNr_ServerHeader 14119
#define sipName_ServerHeader &sipStrings_QtNetwork[14119]
#define sipNameNr_CookieHeader 11687
#define sipName_CookieHeader &sipStrings_QtNetwork[11687]
#define sipNameNr_KnownHeaders 2411
#define sipName_KnownHeaders &sipStrings_QtNetwork[2411]
#define sipNameNr_setOperation 14132
#define sipName_setOperation &sipStrings_QtNetwork[14132]
#define sipNameNr_TimeoutError 3617
#define sipName_TimeoutError &sipStrings_QtNetwork[3617]
#define sipNameNr_peerHostName 14145
#define sipName_peerHostName &sipStrings_QtNetwork[14145]
#define sipNameNr_setQueryType 14158
#define sipName_setQueryType &sipStrings_QtNetwork[14158]
#define sipNameNr_hasRawHeader 14171
#define sipName_hasRawHeader &sipStrings_QtNetwork[14171]
#define sipNameNr_DefaultProxy 14184
#define sipName_DefaultProxy &sipStrings_QtNetwork[14184]
#define sipNameNr_allAddresses 14197
#define sipName_allAddresses &sipStrings_QtNetwork[14197]
#define sipNameNr_CanMulticast 14210
#define sipName_CanMulticast &sipStrings_QtNetwork[14210]
#define sipNameNr_CanBroadcast 14223
#define sipName_CanBroadcast &sipStrings_QtNetwork[14223]
#define sipNameNr_prefixLength 14236
#define sipName_prefixLength &sipStrings_QtNetwork[14236]
#define sipNameNr_setBroadcast 14249
#define sipName_setBroadcast &sipStrings_QtNetwork[14249]
#define sipNameNr_fileMetaData 14262
#define sipName_fileMetaData &sipStrings_QtNetwork[14262]
#define sipNameNr_deleteCookie 14275
#define sipName_deleteCookie &sipStrings_QtNetwork[14275]
#define sipNameNr_updateCookie 14288
#define sipName_updateCookie &sipStrings_QtNetwork[14288]
#define sipNameNr_insertCookie 14301
#define sipName_insertCookie &sipStrings_QtNetwork[14301]
#define sipNameNr_parseCookies 14314
#define sipName_parseCookies &sipStrings_QtNetwork[14314]
#define sipNameNr_capabilities 14327
#define sipName_capabilities &sipStrings_QtNetwork[14327]
#define sipNameNr_Capabilities 259
#define sipName_Capabilities &sipStrings_QtNetwork[259]
#define sipNameNr_proxyFactory 14340
#define sipName_proxyFactory &sipStrings_QtNetwork[14340]
#define sipNameNr_setCookieJar 14353
#define sipName_setCookieJar &sipStrings_QtNetwork[14353]
#define sipNameNr_PutOperation 14366
#define sipName_PutOperation &sipStrings_QtNetwork[14366]
#define sipNameNr_GetOperation 14379
#define sipName_GetOperation &sipStrings_QtNetwork[14379]
#define sipNameNr_QLocalSocket 14392
#define sipName_QLocalSocket &sipStrings_QtNetwork[14392]
#define sipNameNr_removeServer 14405
#define sipName_removeServer &sipStrings_QtNetwork[14405]
#define sipNameNr_QLocalServer 14418
#define sipName_QLocalServer &sipStrings_QtNetwork[14418]
#define sipNameNr_FormDataType 14431
#define sipName_FormDataType &sipStrings_QtNetwork[14431]
#define sipNameNr_setRawHeader 14444
#define sipName_setRawHeader &sipStrings_QtNetwork[14444]
#define sipNameNr_maxFrameSize 14457
#define sipName_maxFrameSize &sipStrings_QtNetwork[14457]
#define sipNameNr_setAddresses 14470
#define sipName_setAddresses &sipStrings_QtNetwork[14470]
#define sipNameNr_HostNotFound 14483
#define sipName_HostNotFound &sipStrings_QtNetwork[14483]
#define sipNameNr_QHostAddress 14496
#define sipName_QHostAddress &sipStrings_QtNetwork[14496]
#define sipNameNr_setPauseMode 14509
#define sipName_setPauseMode &sipStrings_QtNetwork[14509]
#define sipNameNr_ShareAddress 11216
#define sipName_ShareAddress &sipStrings_QtNetwork[11216]
#define sipNameNr_socketOption 14522
#define sipName_socketOption &sipStrings_QtNetwork[14522]
#define sipNameNr_SocketOption 2531
#define sipName_SocketOption &sipStrings_QtNetwork[2531]
#define sipNameNr_setLocalPort 14535
#define sipName_setLocalPort &sipStrings_QtNetwork[14535]
#define sipNameNr_disconnected 14548
#define sipName_disconnected &sipStrings_QtNetwork[14548]
#define sipNameNr_localAddress 14561
#define sipName_localAddress &sipStrings_QtNetwork[14561]
#define sipNameNr_ClosingState 14574
#define sipName_ClosingState &sipStrings_QtNetwork[14574]
#define sipNameNr_NetworkError 3365
#define sipName_NetworkError &sipStrings_QtNetwork[3365]
#define sipNameNr_IPv6Protocol 14587
#define sipName_IPv6Protocol &sipStrings_QtNetwork[14587]
#define sipNameNr_IPv4Protocol 14600
#define sipName_IPv4Protocol &sipStrings_QtNetwork[14600]
#define sipNameNr_HighPriority 14613
#define sipName_HighPriority &sipStrings_QtNetwork[14613]
#define sipNameNr_bytesWritten 14626
#define sipName_bytesWritten &sipStrings_QtNetwork[14626]
#define sipNameNr_bytesToWrite 14639
#define sipName_bytesToWrite &sipStrings_QtNetwork[14639]
#define sipNameNr_lastModified 14652
#define sipName_lastModified &sipStrings_QtNetwork[14652]
#define sipNameNr_readLineData 14665
#define sipName_readLineData &sipStrings_QtNetwork[14665]
#define sipNameNr_isSequential 14678
#define sipName_isSequential &sipStrings_QtNetwork[14678]
#define sipNameNr_setAttribute 14691
#define sipName_setAttribute &sipStrings_QtNetwork[14691]
#define sipNameNr_UnknownError 7708
#define sipName_UnknownError &sipStrings_QtNetwork[7708]
#define sipNameNr_stateChanged 14704
#define sipName_stateChanged &sipStrings_QtNetwork[14704]
#define sipNameNr_defaultValue 14717
#define sipName_defaultValue &sipStrings_QtNetwork[14717]
#define sipNameNr_acceptError 14730
#define sipName_acceptError &sipStrings_QtNetwork[14730]
#define sipNameNr_modeChanged 14742
#define sipName_modeChanged &sipStrings_QtNetwork[14742]
#define sipNameNr_supportsSsl 14754
#define sipName_supportsSsl &sipStrings_QtNetwork[14754]
#define sipNameNr_isEncrypted 14766
#define sipName_isEncrypted &sipStrings_QtNetwork[14766]
#define sipNameNr_setIdentity 14778
#define sipName_setIdentity &sipStrings_QtNetwork[14778]
#define sipNameNr_setProtocol 14790
#define sipName_setProtocol &sipStrings_QtNetwork[14790]
#define sipNameNr_isSupported 14802
#define sipName_isSupported &sipStrings_QtNetwork[14802]
#define sipNameNr_certificate 14814
#define sipName_certificate &sipStrings_QtNetwork[14814]
#define sipNameNr_subjectInfo 14826
#define sipName_subjectInfo &sipStrings_QtNetwork[14826]
#define sipNameNr_CountryName 14838
#define sipName_CountryName &sipStrings_QtNetwork[14838]
#define sipNameNr_SubjectInfo 2765
#define sipName_SubjectInfo &sipStrings_QtNetwork[2765]
#define sipNameNr_AnyProtocol 14850
#define sipName_AnyProtocol &sipStrings_QtNetwork[14850]
#define sipNameNr_SslProtocol 9881
#define sipName_SslProtocol &sipStrings_QtNetwork[9881]
#define sipNameNr_UsagePolicy 2794
#define sipName_UsagePolicy &sipStrings_QtNetwork[2794]
#define sipNameNr_LoadControl 954
#define sipName_LoadControl &sipStrings_QtNetwork[954]
#define sipNameNr_AlwaysCache 14862
#define sipName_AlwaysCache &sipStrings_QtNetwork[14862]
#define sipNameNr_PreferCache 14874
#define sipName_PreferCache &sipStrings_QtNetwork[14874]
#define sipNameNr_setFinished 14886
#define sipName_setFinished &sipStrings_QtNetwork[14886]
#define sipNameNr_Socks5Proxy 14898
#define sipName_Socks5Proxy &sipStrings_QtNetwork[14898]
#define sipNameNr_isTemporary 14910
#define sipName_isTemporary &sipStrings_QtNetwork[14910]
#define sipNameNr_isPermanent 14922
#define sipName_isPermanent &sipStrings_QtNetwork[14922]
#define sipNameNr_DnsEligible 14934
#define sipName_DnsEligible &sipStrings_QtNetwork[14934]
#define sipNameNr_setHopLimit 14946
#define sipName_setHopLimit &sipStrings_QtNetwork[14946]
#define sipNameNr_setHttpOnly 14958
#define sipName_setHttpOnly &sipStrings_QtNetwork[14958]
#define sipNameNr_BearerWiMAX 14970
#define sipName_BearerWiMAX &sipStrings_QtNetwork[14970]
#define sipNameNr_BearerWCDMA 14982
#define sipName_BearerWCDMA &sipStrings_QtNetwork[14982]
#define sipNameNr_serverError 14994
#define sipName_serverError &sipStrings_QtNetwork[14994]
#define sipNameNr_isListening 15006
#define sipName_isListening &sipStrings_QtNetwork[15006]
#define sipNameNr_setBoundary 15018
#define sipName_setBoundary &sipStrings_QtNetwork[15018]
#define sipNameNr_RelatedType 15030
#define sipName_RelatedType &sipStrings_QtNetwork[15030]
#define sipNameNr_ContentType 3506
#define sipName_ContentType &sipStrings_QtNetwork[3506]
#define sipNameNr_PolicyFlags 5211
#define sipName_PolicyFlags &sipStrings_QtNetwork[5211]
#define sipNameNr_QHstsPolicy 15042
#define sipName_QHstsPolicy &sipStrings_QtNetwork[15042]
#define sipNameNr_setLookupId 15054
#define sipName_setLookupId &sipStrings_QtNetwork[15054]
#define sipNameNr_setHostName 15066
#define sipName_setHostName &sipStrings_QtNetwork[15066]
#define sipNameNr_isBroadcast 15078
#define sipName_isBroadcast &sipStrings_QtNetwork[15078]
#define sipNameNr_isSiteLocal 15090
#define sipName_isSiteLocal &sipStrings_QtNetwork[15090]
#define sipNameNr_isLinkLocal 15102
#define sipName_isLinkLocal &sipStrings_QtNetwork[15102]
#define sipNameNr_isMulticast 15114
#define sipName_isMulticast &sipStrings_QtNetwork[15114]
#define sipNameNr_parseSubnet 15126
#define sipName_parseSubnet &sipStrings_QtNetwork[15126]
#define sipNameNr_typeChanged 15138
#define sipName_typeChanged &sipStrings_QtNetwork[15138]
#define sipNameNr_nameChanged 15150
#define sipName_nameChanged &sipStrings_QtNetwork[15150]
#define sipNameNr_textRecords 15162
#define sipName_textRecords &sipStrings_QtNetwork[15162]
#define sipNameNr_protocolTag 15174
#define sipName_protocolTag &sipStrings_QtNetwork[15174]
#define sipNameNr_setPeerName 15186
#define sipName_setPeerName &sipStrings_QtNetwork[15186]
#define sipNameNr_setPeerPort 15198
#define sipName_setPeerPort &sipStrings_QtNetwork[15198]
#define sipNameNr_peerAddress 15210
#define sipName_peerAddress &sipStrings_QtNetwork[15210]
#define sipNameNr_SocketState 2079
#define sipName_SocketState &sipStrings_QtNetwork[2079]
#define sipNameNr_SocketError 2110
#define sipName_SocketError &sipStrings_QtNetwork[2110]
#define sipNameNr_fromEncoded 15222
#define sipName_fromEncoded &sipStrings_QtNetwork[15222]
#define sipNameNr_setPassword 15234
#define sipName_setPassword &sipStrings_QtNetwork[15234]
#define sipNameNr_setPriority 15246
#define sipName_setPriority &sipStrings_QtNetwork[15246]
#define sipNameNr_LowPriority 15258
#define sipName_LowPriority &sipStrings_QtNetwork[15258]
#define sipNameNr_FixedString 15270
#define sipName_FixedString &sipStrings_QtNetwork[15270]
#define sipNameNr_customEvent 15282
#define sipName_customEvent &sipStrings_QtNetwork[15282]
#define sipNameNr_eventFilter 15294
#define sipName_eventFilter &sipStrings_QtNetwork[15294]
#define sipNameNr_errorString 15306
#define sipName_errorString &sipStrings_QtNetwork[15306]
#define sipNameNr_Unspecified 15318
#define sipName_Unspecified &sipStrings_QtNetwork[15318]
#define sipNameNr_canReadLine 15330
#define sipName_canReadLine &sipStrings_QtNetwork[15330]
#define sipNameNr_QUdpSocket 15342
#define sipName_QUdpSocket &sipStrings_QtNetwork[15342]
#define sipNameNr_serverPort 15353
#define sipName_serverPort &sipStrings_QtNetwork[15353]
#define sipNameNr_QTcpServer 15364
#define sipName_QTcpServer &sipStrings_QtNetwork[15364]
#define sipNameNr_VerifyPeer 12263
#define sipName_VerifyPeer &sipStrings_QtNetwork[12263]
#define sipNameNr_VerifyNone 15375
#define sipName_VerifyNone &sipStrings_QtNetwork[15375]
#define sipNameNr_QSslSocket 15386
#define sipName_QSslSocket &sipStrings_QtNetwork[15386]
#define sipNameNr_QTcpSocket 15397
#define sipName_QTcpSocket &sipStrings_QtNetwork[15397]
#define sipNameNr_setCiphers 15408
#define sipName_setCiphers &sipStrings_QtNetwork[15408]
#define sipNameNr_privateKey 15419
#define sipName_privateKey &sipStrings_QtNetwork[15419]
#define sipNameNr_QSslCipher 15430
#define sipName_QSslCipher &sipStrings_QtNetwork[15430]
#define sipNameNr_isCritical 15441
#define sipName_isCritical &sipStrings_QtNetwork[15441]
#define sipNameNr_passPhrase 15452
#define sipName_passPhrase &sipStrings_QtNetwork[15452]
#define sipNameNr_extensions 15463
#define sipName_extensions &sipStrings_QtNetwork[15463]
#define sipNameNr_fromDevice 15474
#define sipName_fromDevice &sipStrings_QtNetwork[15474]
#define sipNameNr_expiryDate 15485
#define sipName_expiryDate &sipStrings_QtNetwork[15485]
#define sipNameNr_issuerInfo 15496
#define sipName_issuerInfo &sipStrings_QtNetwork[15496]
#define sipNameNr_CommonName 15507
#define sipName_CommonName &sipStrings_QtNetwork[15507]
#define sipNameNr_SslOptions 10844
#define sipName_SslOptions &sipStrings_QtNetwork[10844]
#define sipNameNr_TlsV1SslV3 15518
#define sipName_TlsV1SslV3 &sipStrings_QtNetwork[15518]
#define sipNameNr_EmailEntry 15529
#define sipName_EmailEntry &sipStrings_QtNetwork[15529]
#define sipNameNr_PrivateKey 13229
#define sipName_PrivateKey &sipStrings_QtNetwork[13229]
#define sipNameNr_Superseded 15540
#define sipName_Superseded &sipStrings_QtNetwork[15540]
#define sipNameNr_activeTime 15551
#define sipName_activeTime &sipStrings_QtNetwork[15551]
#define sipNameNr_Connecting 15562
#define sipName_Connecting &sipStrings_QtNetwork[15562]
#define sipNameNr_ETagHeader 15573
#define sipName_ETagHeader &sipStrings_QtNetwork[15573]
#define sipNameNr_setRequest 15584
#define sipName_setRequest &sipStrings_QtNetwork[15584]
#define sipNameNr_redirected 15595
#define sipName_redirected &sipStrings_QtNetwork[15595]
#define sipNameNr_queryProxy 15606
#define sipName_queryProxy &sipStrings_QtNetwork[15606]
#define sipNameNr_SctpServer 15617
#define sipName_SctpServer &sipStrings_QtNetwork[15617]
#define sipNameNr_UrlRequest 15628
#define sipName_UrlRequest &sipStrings_QtNetwork[15628]
#define sipNameNr_Ieee802154 15639
#define sipName_Ieee802154 &sipStrings_QtNetwork[15639]
#define sipNameNr_IsLoopBack 15650
#define sipName_IsLoopBack &sipStrings_QtNetwork[15650]
#define sipNameNr_setNetmask 15661
#define sipName_setNetmask &sipStrings_QtNetwork[15661]
#define sipNameNr_senderPort 15672
#define sipName_senderPort &sipStrings_QtNetwork[15672]
#define sipNameNr_allCookies 15683
#define sipName_allCookies &sipStrings_QtNetwork[15683]
#define sipNameNr_isHttpOnly 15694
#define sipName_isHttpOnly &sipStrings_QtNetwork[15694]
#define sipNameNr_bearerType 15705
#define sipName_bearerType &sipStrings_QtNetwork[15705]
#define sipNameNr_BearerEVDO 15716
#define sipName_BearerEVDO &sipStrings_QtNetwork[15716]
#define sipNameNr_BearerHSPA 15727
#define sipName_BearerHSPA &sipStrings_QtNetwork[15727]
#define sipNameNr_BearerWLAN 15738
#define sipName_BearerWLAN &sipStrings_QtNetwork[15738]
#define sipNameNr_BearerType 1091
#define sipName_BearerType &sipStrings_QtNetwork[1091]
#define sipNameNr_StateFlags 1125
#define sipName_StateFlags &sipStrings_QtNetwork[1125]
#define sipNameNr_Discovered 15749
#define sipName_Discovered &sipStrings_QtNetwork[15749]
#define sipNameNr_UserChoice 15760
#define sipName_UserChoice &sipStrings_QtNetwork[15760]
#define sipNameNr_identifier 15771
#define sipName_identifier &sipStrings_QtNetwork[15771]
#define sipNameNr_Capability 343
#define sipName_Capability &sipStrings_QtNetwork[343]
#define sipNameNr_Accessible 7983
#define sipName_Accessible &sipStrings_QtNetwork[7983]
#define sipNameNr_serverName 15782
#define sipName_serverName &sipStrings_QtNetwork[15782]
#define sipNameNr_PolicyFlag 5837
#define sipName_PolicyFlag &sipStrings_QtNetwork[5837]
#define sipNameNr_lookupHost 15793
#define sipName_lookupHost &sipStrings_QtNetwork[15793]
#define sipNameNr_Q_IPV6ADDR 15804
#define sipName_Q_IPV6ADDR &sipStrings_QtNetwork[15804]
#define sipNameNr_isLoopback 15815
#define sipName_isLoopback &sipStrings_QtNetwork[15815]
#define sipNameNr_isInSubnet 15826
#define sipName_isInSubnet &sipStrings_QtNetwork[15826]
#define sipNameNr_setScopeId 15837
#define sipName_setScopeId &sipStrings_QtNetwork[15837]
#define sipNameNr_setAddress 15848
#define sipName_setAddress &sipStrings_QtNetwork[15848]
#define sipNameNr_nameserver 15859
#define sipName_nameserver &sipStrings_QtNetwork[15859]
#define sipNameNr_QDnsLookup 15870
#define sipName_QDnsLookup &sipStrings_QtNetwork[15870]
#define sipNameNr_preference 15881
#define sipName_preference &sipStrings_QtNetwork[15881]
#define sipNameNr_timeToLive 15892
#define sipName_timeToLive &sipStrings_QtNetwork[15892]
#define sipNameNr_PauseModes 3563
#define sipName_PauseModes &sipStrings_QtNetwork[3563]
#define sipNameNr_PauseNever 15903
#define sipName_PauseNever &sipStrings_QtNetwork[15903]
#define sipNameNr_socketType 15914
#define sipName_socketType &sipStrings_QtNetwork[15914]
#define sipNameNr_BoundState 15925
#define sipName_BoundState &sipStrings_QtNetwork[15925]
#define sipNameNr_SctpSocket 15936
#define sipName_SctpSocket &sipStrings_QtNetwork[15936]
#define sipNameNr_SocketType 3703
#define sipName_SocketType &sipStrings_QtNetwork[3703]
#define sipNameNr_saveToDisk 15947
#define sipName_saveToDisk &sipStrings_QtNetwork[15947]
#define sipNameNr_rawHeaders 15958
#define sipName_rawHeaders &sipStrings_QtNetwork[15958]
#define sipNameNr_attributes 15969
#define sipName_attributes &sipStrings_QtNetwork[15969]
#define sipNameNr_isFinished 15980
#define sipName_isFinished &sipStrings_QtNetwork[15980]
#define sipNameNr_childEvent 15991
#define sipName_childEvent &sipStrings_QtNetwork[15991]
#define sipNameNr_timerEvent 16002
#define sipName_timerEvent &sipStrings_QtNetwork[16002]
#define sipNameNr___rshift__ 16013
#define sipName___rshift__ &sipStrings_QtNetwork[16013]
#define sipNameNr___lshift__ 16024
#define sipName___lshift__ &sipStrings_QtNetwork[16024]
#define sipNameNr___invert__ 16035
#define sipName___invert__ &sipStrings_QtNetwork[16035]
#define sipNameNr_QueryPeer 16046
#define sipName_QueryPeer &sipStrings_QtNetwork[16046]
#define sipNameNr_QSslError 16056
#define sipName_QSslError &sipStrings_QtNetwork[16056]
#define sipNameNr_shortName 16066
#define sipName_shortName &sipStrings_QtNetwork[16066]
#define sipNameNr_publicKey 16076
#define sipName_publicKey &sipStrings_QtNetwork[16076]
#define sipNameNr_SslOption 11514
#define sipName_SslOption &sipStrings_QtNetwork[11514]
#define sipNameNr_PublicKey 2264
#define sipName_PublicKey &sipStrings_QtNetwork[2264]
#define sipNameNr_algorithm 16086
#define sipName_algorithm &sipStrings_QtNetwork[16086]
#define sipNameNr_responder 16096
#define sipName_responder &sipStrings_QtNetwork[16096]
#define sipNameNr_interface 16106
#define sipName_interface &sipStrings_QtNetwork[16106]
#define sipNameNr_Connected 11236
#define sipName_Connected &sipStrings_QtNetwork[11236]
#define sipNameNr_Automatic 16116
#define sipName_Automatic &sipStrings_QtNetwork[16116]
#define sipNameNr_Attribute 421
#define sipName_Attribute &sipStrings_QtNetwork[421]
#define sipNameNr_operation 16126
#define sipName_operation &sipStrings_QtNetwork[16126]
#define sipNameNr_queryType 16136
#define sipName_queryType &sipStrings_QtNetwork[16136]
#define sipNameNr_TcpServer 15365
#define sipName_TcpServer &sipStrings_QtNetwork[15365]
#define sipNameNr_QueryType 2504
#define sipName_QueryType &sipStrings_QtNetwork[2504]
#define sipNameNr_rawHeader 16146
#define sipName_rawHeader &sipStrings_QtNetwork[16146]
#define sipNameNr_HttpProxy 16156
#define sipName_HttpProxy &sipStrings_QtNetwork[16156]
#define sipNameNr_ProxyType 5113
#define sipName_ProxyType &sipStrings_QtNetwork[5113]
#define sipNameNr_Ieee80216 16166
#define sipName_Ieee80216 &sipStrings_QtNetwork[16166]
#define sipNameNr_SixLoWPAN 16176
#define sipName_SixLoWPAN &sipStrings_QtNetwork[16176]
#define sipNameNr_Ieee80211 16186
#define sipName_Ieee80211 &sipStrings_QtNetwork[16186]
#define sipNameNr_IsRunning 16196
#define sipName_IsRunning &sipStrings_QtNetwork[16196]
#define sipNameNr_broadcast 16206
#define sipName_broadcast &sipStrings_QtNetwork[16206]
#define sipNameNr_makeReply 16216
#define sipName_makeReply &sipStrings_QtNetwork[16216]
#define sipNameNr_setSender 16226
#define sipName_setSender &sipStrings_QtNetwork[16226]
#define sipNameNr_normalize 16236
#define sipName_normalize &sipStrings_QtNetwork[16236]
#define sipNameNr_toRawForm 16246
#define sipName_toRawForm &sipStrings_QtNetwork[16246]
#define sipNameNr_setDomain 16256
#define sipName_setDomain &sipStrings_QtNetwork[16256]
#define sipNameNr_setSecure 16266
#define sipName_setSecure &sipStrings_QtNetwork[16266]
#define sipNameNr_BearerLTE 16276
#define sipName_BearerLTE &sipStrings_QtNetwork[16276]
#define sipNameNr_StateFlag 1325
#define sipName_StateFlag &sipStrings_QtNetwork[1325]
#define sipNameNr_sslErrors 16286
#define sipName_sslErrors &sipStrings_QtNetwork[16286]
#define sipNameNr_encrypted 16296
#define sipName_encrypted &sipStrings_QtNetwork[16296]
#define sipNameNr_cookieJar 16306
#define sipName_cookieJar &sipStrings_QtNetwork[16306]
#define sipNameNr_Operation 1391
#define sipName_Operation &sipStrings_QtNetwork[1391]
#define sipNameNr_MixedType 16316
#define sipName_MixedType &sipStrings_QtNetwork[16316]
#define sipNameNr_setHeader 16326
#define sipName_setHeader &sipStrings_QtNetwork[16326]
#define sipNameNr_QHttpPart 16336
#define sipName_QHttpPart &sipStrings_QtNetwork[16336]
#define sipNameNr_isExpired 16346
#define sipName_isExpired &sipStrings_QtNetwork[16346]
#define sipNameNr_setExpiry 16356
#define sipName_setExpiry &sipStrings_QtNetwork[16356]
#define sipNameNr_addresses 16366
#define sipName_addresses &sipStrings_QtNetwork[16366]
#define sipNameNr_QHostInfo 16376
#define sipName_QHostInfo &sipStrings_QtNetwork[16376]
#define sipNameNr_LocalHost 11151
#define sipName_LocalHost &sipStrings_QtNetwork[11151]
#define sipNameNr_Broadcast 14226
#define sipName_Broadcast &sipStrings_QtNetwork[14226]
#define sipNameNr_setOption 16386
#define sipName_setOption &sipStrings_QtNetwork[16386]
#define sipNameNr_pauseMode 16396
#define sipName_pauseMode &sipStrings_QtNetwork[16396]
#define sipNameNr_PauseMode 4190
#define sipName_PauseMode &sipStrings_QtNetwork[4190]
#define sipNameNr_connected 8831
#define sipName_connected &sipStrings_QtNetwork[8831]
#define sipNameNr_hostFound 16406
#define sipName_hostFound &sipStrings_QtNetwork[16406]
#define sipNameNr_localPort 16416
#define sipName_localPort &sipStrings_QtNetwork[16416]
#define sipNameNr_UdpSocket 15343
#define sipName_UdpSocket &sipStrings_QtNetwork[15343]
#define sipNameNr_TcpSocket 15398
#define sipName_TcpSocket &sipStrings_QtNetwork[15398]
#define sipNameNr_cacheSize 16426
#define sipName_cacheSize &sipStrings_QtNetwork[16426]
#define sipNameNr_isRunning 16436
#define sipName_isRunning &sipStrings_QtNetwork[16436]
#define sipNameNr_attribute 16446
#define sipName_attribute &sipStrings_QtNetwork[16446]
#define sipNameNr_Undefined 16456
#define sipName_Undefined &sipStrings_QtNetwork[16456]
#define sipNameNr_writeData 16466
#define sipName_writeData &sipStrings_QtNetwork[16466]
#define sipNameNr___index__ 16476
#define sipName___index__ &sipStrings_QtNetwork[16476]
#define sipNameNr_identity 16486
#define sipName_identity &sipStrings_QtNetwork[16486]
#define sipNameNr_SslError 8312
#define sipName_SslError &sipStrings_QtNetwork[8312]
#define sipNameNr_longName 16495
#define sipName_longName &sipStrings_QtNetwork[16495]
#define sipNameNr_encoding 16504
#define sipName_encoding &sipStrings_QtNetwork[16504]
#define sipNameNr_usedBits 16513
#define sipName_usedBits &sipStrings_QtNetwork[16513]
#define sipNameNr_fromData 16522
#define sipName_fromData &sipStrings_QtNetwork[16522]
#define sipNameNr_fromPath 16531
#define sipName_fromPath &sipStrings_QtNetwork[16531]
#define sipNameNr_DtlsV1_2 16540
#define sipName_DtlsV1_2 &sipStrings_QtNetwork[16540]
#define sipNameNr_DtlsV1_0 16549
#define sipName_DtlsV1_0 &sipStrings_QtNetwork[16549]
#define sipNameNr_DnsEntry 16558
#define sipName_DnsEntry &sipStrings_QtNetwork[16558]
#define sipNameNr_NoPolicy 16567
#define sipName_NoPolicy &sipStrings_QtNetwork[16567]
#define sipNameNr_Ieee1394 16576
#define sipName_Ieee1394 &sipStrings_QtNetwork[16576]
#define sipNameNr_Ethernet 12700
#define sipName_Ethernet &sipStrings_QtNetwork[12700]
#define sipNameNr_Loopback 15817
#define sipName_Loopback &sipStrings_QtNetwork[15817]
#define sipNameNr_hopLimit 16585
#define sipName_hopLimit &sipStrings_QtNetwork[16585]
#define sipNameNr_isSecure 16594
#define sipName_isSecure &sipStrings_QtNetwork[16594]
#define sipNameNr_Bearer4G 16603
#define sipName_Bearer4G &sipStrings_QtNetwork[16603]
#define sipNameNr_Bearer3G 16612
#define sipName_Bearer3G &sipStrings_QtNetwork[16612]
#define sipNameNr_Bearer2G 16621
#define sipName_Bearer2G &sipStrings_QtNetwork[16621]
#define sipNameNr_isOnline 16630
#define sipName_isOnline &sipStrings_QtNetwork[16630]
#define sipNameNr_storeDir 16639
#define sipName_storeDir &sipStrings_QtNetwork[16639]
#define sipNameNr_setCache 16648
#define sipName_setCache &sipStrings_QtNetwork[16648]
#define sipNameNr_timedOut 16657
#define sipName_timedOut &sipStrings_QtNetwork[16657]
#define sipNameNr_boundary 16666
#define sipName_boundary &sipStrings_QtNetwork[16666]
#define sipNameNr_fromName 16675
#define sipName_fromName &sipStrings_QtNetwork[16675]
#define sipNameNr_lookupId 16684
#define sipName_lookupId &sipStrings_QtNetwork[16684]
#define sipNameNr_setError 16693
#define sipName_setError &sipStrings_QtNetwork[16693]
#define sipNameNr_isGlobal 16702
#define sipName_isGlobal &sipStrings_QtNetwork[16702]
#define sipNameNr_exchange 16711
#define sipName_exchange &sipStrings_QtNetwork[16711]
#define sipNameNr_BindMode 4713
#define sipName_BindMode &sipStrings_QtNetwork[4713]
#define sipNameNr_BindFlag 4739
#define sipName_BindFlag &sipStrings_QtNetwork[4739]
#define sipNameNr_setProxy 16720
#define sipName_setProxy &sipStrings_QtNetwork[16720]
#define sipNameNr_peerName 16729
#define sipName_peerName &sipStrings_QtNetwork[16729]
#define sipNameNr_peerPort 16738
#define sipName_peerPort &sipStrings_QtNetwork[16738]
#define sipNameNr_protocol 16747
#define sipName_protocol &sipStrings_QtNetwork[16747]
#define sipNameNr_hostName 16756
#define sipName_hostName &sipStrings_QtNetwork[16756]
#define sipNameNr_metaData 16765
#define sipName_metaData &sipStrings_QtNetwork[16765]
#define sipNameNr_password 16774
#define sipName_password &sipStrings_QtNetwork[16774]
#define sipNameNr_Priority 4453
#define sipName_Priority &sipStrings_QtNetwork[4453]
#define sipNameNr_setValue 16783
#define sipName_setValue &sipStrings_QtNetwork[16783]
#define sipNameNr_Wildcard 16792
#define sipName_Wildcard &sipStrings_QtNetwork[16792]
#define sipNameNr_children 16801
#define sipName_children &sipStrings_QtNetwork[16801]
#define sipNameNr_priority 16810
#define sipName_priority &sipStrings_QtNetwork[16810]
#define sipNameNr_toString 16819
#define sipName_toString &sipStrings_QtNetwork[16819]
#define sipNameNr_readData 16828
#define sipName_readData &sipStrings_QtNetwork[16828]
#define sipNameNr_finished 16837
#define sipName_finished &sipStrings_QtNetwork[16837]
#define sipNameNr___hash__ 16846
#define sipName___hash__ &sipStrings_QtNetwork[16846]
#define sipNameNr___bool__ 16855
#define sipName___bool__ &sipStrings_QtNetwork[16855]
#define sipNameNr___ixor__ 16864
#define sipName___ixor__ &sipStrings_QtNetwork[16864]
#define sipNameNr___iand__ 16873
#define sipName___iand__ &sipStrings_QtNetwork[16873]
#define sipNameNr_SslMode 8233
#define sipName_SslMode &sipStrings_QtNetwork[8233]
#define sipNameNr_QSslKey 16882
#define sipName_QSslKey &sipStrings_QtNetwork[16882]
#define sipNameNr_ciphers 16890
#define sipName_ciphers &sipStrings_QtNetwork[16890]
#define sipNameNr_TlsV1_3 16898
#define sipName_TlsV1_3 &sipStrings_QtNetwork[16898]
#define sipNameNr_TlsV1_2 16906
#define sipName_TlsV1_2 &sipStrings_QtNetwork[16906]
#define sipNameNr_TlsV1_1 16914
#define sipName_TlsV1_1 &sipStrings_QtNetwork[16914]
#define sipNameNr_TlsV1_0 16922
#define sipName_TlsV1_0 &sipStrings_QtNetwork[16922]
#define sipNameNr_KeyType 13302
#define sipName_KeyType &sipStrings_QtNetwork[13302]
#define sipNameNr_Revoked 8988
#define sipName_Revoked &sipStrings_QtNetwork[8988]
#define sipNameNr_migrate 16930
#define sipName_migrate &sipStrings_QtNetwork[16930]
#define sipNameNr_Roaming 5768
#define sipName_Roaming &sipStrings_QtNetwork[5768]
#define sipNameNr_Closing 16938
#define sipName_Closing &sipStrings_QtNetwork[16938]
#define sipNameNr_UserMax 16946
#define sipName_UserMax &sipStrings_QtNetwork[16946]
#define sipNameNr_manager 16954
#define sipName_manager &sipStrings_QtNetwork[16954]
#define sipNameNr_NoProxy 16962
#define sipName_NoProxy &sipStrings_QtNetwork[16962]
#define sipNameNr_Virtual 16970
#define sipName_Virtual &sipStrings_QtNetwork[16970]
#define sipNameNr_RawForm 5744
#define sipName_RawForm &sipStrings_QtNetwork[5744]
#define sipNameNr_purpose 16978
#define sipName_purpose &sipStrings_QtNetwork[16978]
#define sipNameNr_Defined 16986
#define sipName_Defined &sipStrings_QtNetwork[16986]
#define sipNameNr_Purpose 2021
#define sipName_Purpose &sipStrings_QtNetwork[2021]
#define sipNameNr_request 16994
#define sipName_request &sipStrings_QtNetwork[16994]
#define sipNameNr_setBody 17002
#define sipName_setBody &sipStrings_QtNetwork[17002]
#define sipNameNr_isEqual 17010
#define sipName_isEqual &sipStrings_QtNetwork[17010]
#define sipNameNr_netmask 17018
#define sipName_netmask &sipStrings_QtNetwork[17018]
#define sipNameNr_scopeId 17026
#define sipName_scopeId &sipStrings_QtNetwork[17026]
#define sipNameNr_AnyIPv6 17034
#define sipName_AnyIPv6 &sipStrings_QtNetwork[17034]
#define sipNameNr_AnyIPv4 17042
#define sipName_AnyIPv4 &sipStrings_QtNetwork[17042]
#define sipNameNr_setName 17050
#define sipName_setName &sipStrings_QtNetwork[17050]
#define sipNameNr_setUser 17058
#define sipName_setUser &sipStrings_QtNetwork[17058]
#define sipNameNr_prepare 17066
#define sipName_prepare &sipStrings_QtNetwork[17066]
#define sipNameNr_setPort 17074
#define sipName_setPort &sipStrings_QtNetwork[17074]
#define sipNameNr_setHost 17082
#define sipName_setHost &sipStrings_QtNetwork[17082]
#define sipNameNr_subject 17090
#define sipName_subject &sipStrings_QtNetwork[17090]
#define sipNameNr_Unknown 4324
#define sipName_Unknown &sipStrings_QtNetwork[4324]
#define sipNameNr_maxSize 17098
#define sipName_maxSize &sipStrings_QtNetwork[17098]
#define sipNameNr_address 17106
#define sipName_address &sipStrings_QtNetwork[17106]
#define sipNameNr_timeout 17114
#define sipName_timeout &sipStrings_QtNetwork[17114]
#define sipNameNr_setType 17122
#define sipName_setType &sipStrings_QtNetwork[17122]
#define sipNameNr_setPath 17130
#define sipName_setPath &sipStrings_QtNetwork[17130]
#define sipNameNr_version 9425
#define sipName_version &sipStrings_QtNetwork[9425]
#define sipNameNr_Invalid 17138
#define sipName_Invalid &sipStrings_QtNetwork[17138]
#define sipNameNr_NoError 17146
#define sipName_NoError &sipStrings_QtNetwork[17146]
#define sipNameNr_isEmpty 17154
#define sipName_isEmpty &sipStrings_QtNetwork[17154]
#define sipNameNr_options 17162
#define sipName_options &sipStrings_QtNetwork[17162]
#define sipNameNr_setData 17170
#define sipName_setData &sipStrings_QtNetwork[17170]
#define sipNameNr_isValid 17178
#define sipName_isValid &sipStrings_QtNetwork[17178]
#define sipNameNr___xor__ 17186
#define sipName___xor__ &sipStrings_QtNetwork[17186]
#define sipNameNr___ior__ 17194
#define sipName___ior__ &sipStrings_QtNetwork[17194]
#define sipNameNr___and__ 17202
#define sipName___and__ &sipStrings_QtNetwork[17202]
#define sipNameNr___int__ 17210
#define sipName___int__ &sipStrings_QtNetwork[17210]
#define sipNameNr_verify 17218
#define sipName_verify &sipStrings_QtNetwork[17218]
#define sipNameNr_toText 17225
#define sipName_toText &sipStrings_QtNetwork[17225]
#define sipNameNr_digest 17232
#define sipName_digest &sipStrings_QtNetwork[17232]
#define sipNameNr_Opaque 17239
#define sipName_Opaque &sipStrings_QtNetwork[17239]
#define sipNameNr_closed 17246
#define sipName_closed &sipStrings_QtNetwork[17246]
#define sipNameNr_opened 17253
#define sipName_opened &sipStrings_QtNetwork[17253]
#define sipNameNr_reject 17260
#define sipName_reject &sipStrings_QtNetwork[17260]
#define sipNameNr_Manual 17267
#define sipName_Manual &sipStrings_QtNetwork[17267]
#define sipNameNr_Phonet 17274
#define sipName_Phonet &sipStrings_QtNetwork[17274]
#define sipNameNr_CanBus 17281
#define sipName_CanBus &sipStrings_QtNetwork[17281]
#define sipNameNr_expire 17288
#define sipName_expire &sipStrings_QtNetwork[17288]
#define sipNameNr_domain 17295
#define sipName_domain &sipStrings_QtNetwork[17295]
#define sipNameNr_Active 17302
#define sipName_Active &sipStrings_QtNetwork[17302]
#define sipNameNr_listen 17309
#define sipName_listen &sipStrings_QtNetwork[17309]
#define sipNameNr_header 17316
#define sipName_header &sipStrings_QtNetwork[17316]
#define sipNameNr_expiry 17323
#define sipName_expiry &sipStrings_QtNetwork[17323]
#define sipNameNr_lookup 17330
#define sipName_lookup &sipStrings_QtNetwork[17330]
#define sipNameNr_weight 17337
#define sipName_weight &sipStrings_QtNetwork[17337]
#define sipNameNr_setUrl 17344
#define sipName_setUrl &sipStrings_QtNetwork[17344]
#define sipNameNr_isOpen 17351
#define sipName_isOpen &sipStrings_QtNetwork[17351]
#define sipNameNr_handle 17358
#define sipName_handle &sipStrings_QtNetwork[17358]
#define sipNameNr_ignore 17365
#define sipName_ignore &sipStrings_QtNetwork[17365]
#define sipNameNr_accept 17372
#define sipName_accept &sipStrings_QtNetwork[17372]
#define sipNameNr_option 17379
#define sipName_option &sipStrings_QtNetwork[17379]
#define sipNameNr_values 17386
#define sipName_values &sipStrings_QtNetwork[17386]
#define sipNameNr_syntax 17393
#define sipName_syntax &sipStrings_QtNetwork[17393]
#define sipNameNr_device 17400
#define sipName_device &sipStrings_QtNetwork[17400]
#define sipNameNr_format 17407
#define sipName_format &sipStrings_QtNetwork[17407]
#define sipNameNr_remove 17414
#define sipName_remove &sipStrings_QtNetwork[17414]
#define sipNameNr_insert 17421
#define sipName_insert &sipStrings_QtNetwork[17421]
#define sipNameNr_append 17428
#define sipName_append &sipStrings_QtNetwork[17428]
#define sipNameNr_length 17435
#define sipName_length &sipStrings_QtNetwork[17435]
#define sipNameNr_isNull 17442
#define sipName_isNull &sipStrings_QtNetwork[17442]
#define sipNameNr_target 17449
#define sipName_target &sipStrings_QtNetwork[17449]
#define sipNameNr_resume 17456
#define sipName_resume &sipStrings_QtNetwork[17456]
#define sipNameNr_parent 17463
#define sipName_parent &sipStrings_QtNetwork[17463]
#define sipNameNr___ne__ 17470
#define sipName___ne__ &sipStrings_QtNetwork[17470]
#define sipNameNr___eq__ 17477
#define sipName___eq__ &sipStrings_QtNetwork[17477]
#define sipNameNr___or__ 17484
#define sipName___or__ &sipStrings_QtNetwork[17484]
#define sipNameNr_toDer 17491
#define sipName_toDer &sipStrings_QtNetwork[17491]
#define sipNameNr_toPem 17497
#define sipName_toPem &sipStrings_QtNetwork[17497]
#define sipNameNr_SslV2 17503
#define sipName_SslV2 &sipStrings_QtNetwork[17503]
#define sipNameNr_SslV3 15523
#define sipName_SslV3 &sipStrings_QtNetwork[15523]
#define sipNameNr_setIp 17509
#define sipName_setIp &sipStrings_QtNetwork[17509]
#define sipNameNr_cache 17515
#define sipName_cache &sipStrings_QtNetwork[17515]
#define sipNameNr_CNAME 17521
#define sipName_CNAME &sipStrings_QtNetwork[17521]
#define sipNameNr_realm 17527
#define sipName_realm &sipStrings_QtNetwork[17527]
#define sipNameNr_proxy 17533
#define sipName_proxy &sipStrings_QtNetwork[17533]
#define sipNameNr_abort 17539
#define sipName_abort &sipStrings_QtNetwork[17539]
#define sipNameNr_query 17545
#define sipName_query &sipStrings_QtNetwork[17545]
#define sipNameNr_error 17551
#define sipName_error &sipStrings_QtNetwork[17551]
#define sipNameNr_reset 17557
#define sipName_reset &sipStrings_QtNetwork[17557]
#define sipNameNr_Error 718
#define sipName_Error &sipStrings_QtNetwork[718]
#define sipNameNr_atEnd 17563
#define sipName_atEnd &sipStrings_QtNetwork[17563]
#define sipNameNr_close 17569
#define sipName_close &sipStrings_QtNetwork[17569]
#define sipNameNr_clear 17575
#define sipName_clear &sipStrings_QtNetwork[17575]
#define sipNameNr_value 17581
#define sipName_value &sipStrings_QtNetwork[17581]
#define sipNameNr_index 17587
#define sipName_index &sipStrings_QtNetwork[17587]
#define sipNameNr_flush 17593
#define sipName_flush &sipStrings_QtNetwork[17593]
#define sipNameNr_flags 17599
#define sipName_flags &sipStrings_QtNetwork[17599]
#define sipNameNr_event 17605
#define sipName_event &sipStrings_QtNetwork[17605]
#define sipNameNr_msecs 17611
#define sipName_msecs &sipStrings_QtNetwork[17611]
#define sipNameNr_state 17617
#define sipName_state &sipStrings_QtNetwork[17617]
#define sipNameNr_State 2085
#define sipName_State &sipStrings_QtNetwork[2085]
#define sipNameNr_QSsl 17623
#define sipName_QSsl &sipStrings_QtNetwork[17623]
#define sipNameNr_None 3317
#define sipName_None &sipStrings_QtNetwork[3317]
#define sipNameNr_Good 17628
#define sipName_Good &sipStrings_QtNetwork[17628]
#define sipNameNr_Wifi 17633
#define sipName_Wifi &sipStrings_QtNetwork[17633]
#define sipNameNr_Fddi 17638
#define sipName_Fddi &sipStrings_QtNetwork[17638]
#define sipNameNr_Slip 17643
#define sipName_Slip &sipStrings_QtNetwork[17643]
#define sipNameNr_IsUp 17648
#define sipName_IsUp &sipStrings_QtNetwork[17648]
#define sipNameNr_form 9504
#define sipName_form &sipStrings_QtNetwork[9504]
#define sipNameNr_Full 17653
#define sipName_Full &sipStrings_QtNetwork[17653]
#define sipNameNr_post 17658
#define sipName_post &sipStrings_QtNetwork[17658]
#define sipNameNr_head 17663
#define sipName_head &sipStrings_QtNetwork[17663]
#define sipNameNr_AAAA 17668
#define sipName_AAAA &sipStrings_QtNetwork[17668]
#define sipNameNr_user 17673
#define sipName_user &sipStrings_QtNetwork[17673]
#define sipNameNr_bind 17678
#define sipName_bind &sipStrings_QtNetwork[17678]
#define sipNameNr_port 7926
#define sipName_port &sipStrings_QtNetwork[7926]
#define sipNameNr_host 17683
#define sipName_host &sipStrings_QtNetwork[17683]
#define sipNameNr_path 17688
#define sipName_path &sipStrings_QtNetwork[17688]
#define sipNameNr_User 17061
#define sipName_User &sipStrings_QtNetwork[17061]
#define sipNameNr_mode 17693
#define sipName_mode &sipStrings_QtNetwork[17693]
#define sipNameNr_Type 1097
#define sipName_Type &sipStrings_QtNetwork[1097]
#define sipNameNr_Null 17444
#define sipName_Null &sipStrings_QtNetwork[17444]
#define sipNameNr_name 17698
#define sipName_name &sipStrings_QtNetwork[17698]
#define sipNameNr_seek 17703
#define sipName_seek &sipStrings_QtNetwork[17703]
#define sipNameNr_open 17708
#define sipName_open &sipStrings_QtNetwork[17708]
#define sipNameNr_size 17713
#define sipName_size &sipStrings_QtNetwork[17713]
#define sipNameNr_type 17718
#define sipName_type &sipStrings_QtNetwork[17718]
#define sipNameNr_swap 17723
#define sipName_swap &sipStrings_QtNetwork[17723]
#define sipNameNr_data 17728
#define sipName_data &sipStrings_QtNetwork[17728]
#define sipNameNr_stop 17733
#define sipName_stop &sipStrings_QtNetwork[17733]
#define sipNameNr_oid 17738
#define sipName_oid &sipStrings_QtNetwork[17738]
#define sipNameNr_Dsa 17742
#define sipName_Dsa &sipStrings_QtNetwork[17742]
#define sipNameNr_Rsa 17746
#define sipName_Rsa &sipStrings_QtNetwork[17746]
#define sipNameNr_Der 17493
#define sipName_Der &sipStrings_QtNetwork[17493]
#define sipNameNr_Pem 17499
#define sipName_Pem &sipStrings_QtNetwork[17499]
#define sipNameNr_Ppp 17750
#define sipName_Ppp &sipStrings_QtNetwork[17750]
#define sipNameNr_put 17754
#define sipName_put &sipStrings_QtNetwork[17754]
#define sipNameNr_get 17452
#define sipName_get &sipStrings_QtNetwork[17452]
#define sipNameNr_Any 17758
#define sipName_Any &sipStrings_QtNetwork[17758]
#define sipNameNr_TXT 17762
#define sipName_TXT &sipStrings_QtNetwork[17762]
#define sipNameNr_SRV 17766
#define sipName_SRV &sipStrings_QtNetwork[17766]
#define sipNameNr_PTR 17770
#define sipName_PTR &sipStrings_QtNetwork[17770]
#define sipNameNr_ANY 17774
#define sipName_ANY &sipStrings_QtNetwork[17774]
#define sipNameNr_url 17778
#define sipName_url &sipStrings_QtNetwork[17778]
#define sipNameNr_pos 17782
#define sipName_pos &sipStrings_QtNetwork[17782]
#define sipNameNr_Dh 17786
#define sipName_Dh &sipStrings_QtNetwork[17786]
#define sipNameNr_Ec 17789
#define sipName_Ec &sipStrings_QtNetwork[17789]
#define sipNameNr_ip 17645
#define sipName_ip &sipStrings_QtNetwork[17645]
#define sipNameNr_NS 17792
#define sipName_NS &sipStrings_QtNetwork[17792]
#define sipNameNr_MX 17795
#define sipName_MX &sipStrings_QtNetwork[17795]
#define sipNameNr_id 6033
#define sipName_id &sipStrings_QtNetwork[6033]
#define sipNameNr_A 14992
#define sipName_A &sipStrings_QtNetwork[14992]

#define sipMalloc                   sipAPI_QtNetwork->api_malloc
#define sipFree                     sipAPI_QtNetwork->api_free
#define sipBuildResult              sipAPI_QtNetwork->api_build_result
#define sipCallMethod               sipAPI_QtNetwork->api_call_method
#define sipCallProcedureMethod      sipAPI_QtNetwork->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtNetwork->api_call_error_handler
#define sipParseResultEx            sipAPI_QtNetwork->api_parse_result_ex
#define sipParseResult              sipAPI_QtNetwork->api_parse_result
#define sipParseArgs                sipAPI_QtNetwork->api_parse_args
#define sipParseKwdArgs             sipAPI_QtNetwork->api_parse_kwd_args
#define sipParsePair                sipAPI_QtNetwork->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtNetwork->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtNetwork->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtNetwork->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtNetwork->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtNetwork->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtNetwork->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtNetwork->api_add_exception
#define sipNoFunction               sipAPI_QtNetwork->api_no_function
#define sipNoMethod                 sipAPI_QtNetwork->api_no_method
#define sipAbstractMethod           sipAPI_QtNetwork->api_abstract_method
#define sipBadClass                 sipAPI_QtNetwork->api_bad_class
#define sipBadCatcherResult         sipAPI_QtNetwork->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtNetwork->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtNetwork->api_bad_operator_arg
#define sipTrace                    sipAPI_QtNetwork->api_trace
#define sipTransferBack             sipAPI_QtNetwork->api_transfer_back
#define sipTransferTo               sipAPI_QtNetwork->api_transfer_to
#define sipTransferBreak            sipAPI_QtNetwork->api_transfer_break
#define sipSimpleWrapper_Type       sipAPI_QtNetwork->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtNetwork->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtNetwork->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtNetwork->api_voidptr_type
#define sipGetPyObject              sipAPI_QtNetwork->api_get_pyobject
#define sipGetAddress               sipAPI_QtNetwork->api_get_address
#define sipGetMixinAddress          sipAPI_QtNetwork->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtNetwork->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtNetwork->api_get_complex_cpp_ptr
#define sipIsPyMethod               sipAPI_QtNetwork->api_is_py_method
#define sipCallHook                 sipAPI_QtNetwork->api_call_hook
#define sipEndThread                sipAPI_QtNetwork->api_end_thread
#define sipConnectRx                sipAPI_QtNetwork->api_connect_rx
#define sipDisconnectRx             sipAPI_QtNetwork->api_disconnect_rx
#define sipRaiseUnknownException    sipAPI_QtNetwork->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtNetwork->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtNetwork->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtNetwork->api_add_type_instance
#define sipFreeSipslot              sipAPI_QtNetwork->api_free_sipslot
#define sipSameSlot                 sipAPI_QtNetwork->api_same_slot
#define sipPySlotExtend             sipAPI_QtNetwork->api_pyslot_extend
#define sipConvertRx                sipAPI_QtNetwork->api_convert_rx
#define sipAddDelayedDtor           sipAPI_QtNetwork->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtNetwork->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtNetwork->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtNetwork->api_force_convert_to_type
#define sipCanConvertToEnum         sipAPI_QtNetwork->api_can_convert_to_enum
#define sipConvertToEnum            sipAPI_QtNetwork->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtNetwork->api_convert_to_bool
#define sipReleaseType              sipAPI_QtNetwork->api_release_type
#define sipConvertFromType          sipAPI_QtNetwork->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtNetwork->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtNetwork->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtNetwork->api_convert_from_enum
#define sipGetState                 sipAPI_QtNetwork->api_get_state
#define sipExportSymbol             sipAPI_QtNetwork->api_export_symbol
#define sipImportSymbol             sipAPI_QtNetwork->api_import_symbol
#define sipFindType                 sipAPI_QtNetwork->api_find_type
#define sipFindNamedEnum            sipAPI_QtNetwork->api_find_named_enum
#define sipBytes_AsChar             sipAPI_QtNetwork->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtNetwork->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtNetwork->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtNetwork->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtNetwork->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtNetwork->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtNetwork->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtNetwork->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtNetwork->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtNetwork->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtNetwork->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtNetwork->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtNetwork->api_convert_from_const_void_ptr_and_size
#define sipInvokeSlot               sipAPI_QtNetwork->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtNetwork->api_invoke_slot_ex
#define sipSaveSlot                 sipAPI_QtNetwork->api_save_slot
#define sipClearAnySlotReference    sipAPI_QtNetwork->api_clear_any_slot_reference
#define sipVisitSlot                sipAPI_QtNetwork->api_visit_slot
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtNetwork->api_deprecated
#define sipGetReference             sipAPI_QtNetwork->api_get_reference
#define sipKeepReference            sipAPI_QtNetwork->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtNetwork->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtNetwork->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtNetwork->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtNetwork->api_type_scope
#define sipResolveTypedef           sipAPI_QtNetwork->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtNetwork->api_register_attribute_getter
#define sipIsAPIEnabled             sipAPI_QtNetwork->api_is_api_enabled
#define sipSetDestroyOnExit         sipAPI_QtNetwork->api_set_destroy_on_exit
#define sipEnableAutoconversion     sipAPI_QtNetwork->api_enable_autoconversion
#define sipEnableOverflowChecking   sipAPI_QtNetwork->api_enable_overflow_checking
#define sipInitMixin                sipAPI_QtNetwork->api_init_mixin
#define sipExportModule             sipAPI_QtNetwork->api_export_module
#define sipInitModule               sipAPI_QtNetwork->api_init_module
#define sipGetInterpreter           sipAPI_QtNetwork->api_get_interpreter
#define sipSetNewUserTypeHandler    sipAPI_QtNetwork->api_set_new_user_type_handler
#define sipSetTypeUserData          sipAPI_QtNetwork->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtNetwork->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtNetwork->api_py_type_dict
#define sipPyTypeName               sipAPI_QtNetwork->api_py_type_name
#define sipGetCFunction             sipAPI_QtNetwork->api_get_c_function
#define sipGetMethod                sipAPI_QtNetwork->api_get_method
#define sipFromMethod               sipAPI_QtNetwork->api_from_method
#define sipGetDate                  sipAPI_QtNetwork->api_get_date
#define sipFromDate                 sipAPI_QtNetwork->api_from_date
#define sipGetDateTime              sipAPI_QtNetwork->api_get_datetime
#define sipFromDateTime             sipAPI_QtNetwork->api_from_datetime
#define sipGetTime                  sipAPI_QtNetwork->api_get_time
#define sipFromTime                 sipAPI_QtNetwork->api_from_time
#define sipIsUserType               sipAPI_QtNetwork->api_is_user_type
#define sipGetFrame                 sipAPI_QtNetwork->api_get_frame
#define sipCheckPluginForType       sipAPI_QtNetwork->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtNetwork->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtNetwork->api_unicode_write
#define sipUnicodeData              sipAPI_QtNetwork->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtNetwork->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtNetwork->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtNetwork->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtNetwork->api_is_derived_class
#define sipGetUserObject            sipAPI_QtNetwork->api_get_user_object
#define sipSetUserObject            sipAPI_QtNetwork->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtNetwork->api_register_event_handler
#define sipLong_AsChar              sipAPI_QtNetwork->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtNetwork->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtNetwork->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtNetwork->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtNetwork->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtNetwork->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtNetwork->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtNetwork->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtNetwork->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtNetwork->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtNetwork->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtNetwork->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtNetwork->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtNetwork->api_register_exit_notifier

/* These are deprecated. */
#define sipMapStringToClass         sipAPI_QtNetwork->api_map_string_to_class
#define sipMapIntToClass            sipAPI_QtNetwork->api_map_int_to_class
#define sipFindClass                sipAPI_QtNetwork->api_find_class
#define sipFindMappedType           sipAPI_QtNetwork->api_find_mapped_type
#define sipConvertToArray           sipAPI_QtNetwork->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtNetwork->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtNetwork->api_enable_gc
#define sipPrintObject              sipAPI_QtNetwork->api_print_object
#define sipWrapper_Check(w)         PyObject_TypeCheck((w), sipAPI_QtNetwork->api_wrapper_type)
#define sipGetWrapper(p, wt)        sipGetPyObject((p), (wt)->wt_td)
#define sipReleaseInstance(p, wt, s)    sipReleaseType((p), (wt)->wt_td, (s))
#define sipReleaseMappedType        sipReleaseType
#define sipCanConvertToInstance(o, wt, f)   sipCanConvertToType((o), (wt)->wt_td, (f))
#define sipCanConvertToMappedType   sipCanConvertToType
#define sipConvertToInstance(o, wt, t, f, s, e)     sipConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipConvertToMappedType      sipConvertToType
#define sipForceConvertToInstance(o, wt, t, f, s, e)    sipForceConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipForceConvertToMappedType sipForceConvertToType
#define sipConvertFromInstance(p, wt, t)    sipConvertFromType((p), (wt)->wt_td, (t))
#define sipConvertFromMappedType    sipConvertFromType
#define sipConvertFromNamedEnum(v, pt)  sipConvertFromEnum((v), ((sipEnumTypeObject *)(pt))->type)
#define sipConvertFromNewInstance(p, wt, t) sipConvertFromNewType((p), (wt)->wt_td, (t))

/* The strings used by this module. */
extern const char sipStrings_QtNetwork[];

#define sipType_QNetworkCacheMetaData sipExportedTypes_QtNetwork[63]
#define sipClass_QNetworkCacheMetaData sipExportedTypes_QtNetwork[63]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkCacheMetaData;

#define sipType_QAbstractNetworkCache sipExportedTypes_QtNetwork[0]
#define sipClass_QAbstractNetworkCache sipExportedTypes_QtNetwork[0]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QAbstractNetworkCache;

#define sipType_QAbstractSocket sipExportedTypes_QtNetwork[1]
#define sipClass_QAbstractSocket sipExportedTypes_QtNetwork[1]->u.td_wrapper_type

#define sipType_QAbstractSocket_PauseMode sipExportedTypes_QtNetwork[5]
#define sipEnum_QAbstractSocket_PauseMode sipExportedTypes_QtNetwork[5]->u.td_py_type

#define sipType_QAbstractSocket_BindFlag sipExportedTypes_QtNetwork[2]
#define sipEnum_QAbstractSocket_BindFlag sipExportedTypes_QtNetwork[2]->u.td_py_type

#define sipType_QAbstractSocket_SocketOption sipExportedTypes_QtNetwork[8]
#define sipEnum_QAbstractSocket_SocketOption sipExportedTypes_QtNetwork[8]->u.td_py_type

#define sipType_QAbstractSocket_SocketState sipExportedTypes_QtNetwork[9]
#define sipEnum_QAbstractSocket_SocketState sipExportedTypes_QtNetwork[9]->u.td_py_type

#define sipType_QAbstractSocket_SocketError sipExportedTypes_QtNetwork[7]
#define sipEnum_QAbstractSocket_SocketError sipExportedTypes_QtNetwork[7]->u.td_py_type

#define sipType_QAbstractSocket_NetworkLayerProtocol sipExportedTypes_QtNetwork[4]
#define sipEnum_QAbstractSocket_NetworkLayerProtocol sipExportedTypes_QtNetwork[4]->u.td_py_type

#define sipType_QAbstractSocket_SocketType sipExportedTypes_QtNetwork[10]
#define sipEnum_QAbstractSocket_SocketType sipExportedTypes_QtNetwork[10]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QAbstractSocket;

#define sipType_QAbstractSocket_BindMode sipExportedTypes_QtNetwork[3]
#define sipClass_QAbstractSocket_BindMode sipExportedTypes_QtNetwork[3]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QAbstractSocket_BindMode;

#define sipType_QAbstractSocket_PauseModes sipExportedTypes_QtNetwork[6]
#define sipClass_QAbstractSocket_PauseModes sipExportedTypes_QtNetwork[6]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QAbstractSocket_PauseModes;

#define sipType_QAuthenticator sipExportedTypes_QtNetwork[11]
#define sipClass_QAuthenticator sipExportedTypes_QtNetwork[11]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QAuthenticator;

#define sipType_QDnsDomainNameRecord sipExportedTypes_QtNetwork[12]
#define sipClass_QDnsDomainNameRecord sipExportedTypes_QtNetwork[12]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsDomainNameRecord;

#define sipType_QDnsHostAddressRecord sipExportedTypes_QtNetwork[13]
#define sipClass_QDnsHostAddressRecord sipExportedTypes_QtNetwork[13]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsHostAddressRecord;

#define sipType_QDnsMailExchangeRecord sipExportedTypes_QtNetwork[17]
#define sipClass_QDnsMailExchangeRecord sipExportedTypes_QtNetwork[17]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsMailExchangeRecord;

#define sipType_QDnsServiceRecord sipExportedTypes_QtNetwork[18]
#define sipClass_QDnsServiceRecord sipExportedTypes_QtNetwork[18]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsServiceRecord;

#define sipType_QDnsTextRecord sipExportedTypes_QtNetwork[19]
#define sipClass_QDnsTextRecord sipExportedTypes_QtNetwork[19]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsTextRecord;

#define sipType_QDnsLookup sipExportedTypes_QtNetwork[14]
#define sipClass_QDnsLookup sipExportedTypes_QtNetwork[14]->u.td_wrapper_type

#define sipType_QDnsLookup_Type sipExportedTypes_QtNetwork[16]
#define sipEnum_QDnsLookup_Type sipExportedTypes_QtNetwork[16]->u.td_py_type

#define sipType_QDnsLookup_Error sipExportedTypes_QtNetwork[15]
#define sipEnum_QDnsLookup_Error sipExportedTypes_QtNetwork[15]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsLookup;

#define sipType_QHostAddress sipExportedTypes_QtNetwork[21]
#define sipClass_QHostAddress sipExportedTypes_QtNetwork[21]->u.td_wrapper_type

#define sipType_QHostAddress_ConversionModeFlag sipExportedTypes_QtNetwork[23]
#define sipEnum_QHostAddress_ConversionModeFlag sipExportedTypes_QtNetwork[23]->u.td_py_type

#define sipType_QHostAddress_SpecialAddress sipExportedTypes_QtNetwork[24]
#define sipEnum_QHostAddress_SpecialAddress sipExportedTypes_QtNetwork[24]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QHostAddress;

#define sipType_QHostAddress_ConversionMode sipExportedTypes_QtNetwork[22]
#define sipClass_QHostAddress_ConversionMode sipExportedTypes_QtNetwork[22]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QHostAddress_ConversionMode;

#define sipType_QHostInfo sipExportedTypes_QtNetwork[25]
#define sipClass_QHostInfo sipExportedTypes_QtNetwork[25]->u.td_wrapper_type

#define sipType_QHostInfo_HostInfoError sipExportedTypes_QtNetwork[26]
#define sipEnum_QHostInfo_HostInfoError sipExportedTypes_QtNetwork[26]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QHostInfo;

#define sipType_QHstsPolicy sipExportedTypes_QtNetwork[27]
#define sipClass_QHstsPolicy sipExportedTypes_QtNetwork[27]->u.td_wrapper_type

#define sipType_QHstsPolicy_PolicyFlag sipExportedTypes_QtNetwork[28]
#define sipEnum_QHstsPolicy_PolicyFlag sipExportedTypes_QtNetwork[28]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QHstsPolicy;

#define sipType_QHstsPolicy_PolicyFlags sipExportedTypes_QtNetwork[29]
#define sipClass_QHstsPolicy_PolicyFlags sipExportedTypes_QtNetwork[29]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QHstsPolicy_PolicyFlags;

#define sipType_QHttp2Configuration sipExportedTypes_QtNetwork[30]
#define sipClass_QHttp2Configuration sipExportedTypes_QtNetwork[30]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QHttp2Configuration;

#define sipType_QHttpPart sipExportedTypes_QtNetwork[33]
#define sipClass_QHttpPart sipExportedTypes_QtNetwork[33]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QHttpPart;

#define sipType_QHttpMultiPart sipExportedTypes_QtNetwork[31]
#define sipClass_QHttpMultiPart sipExportedTypes_QtNetwork[31]->u.td_wrapper_type

#define sipType_QHttpMultiPart_ContentType sipExportedTypes_QtNetwork[32]
#define sipEnum_QHttpMultiPart_ContentType sipExportedTypes_QtNetwork[32]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QHttpMultiPart;

#define sipType_QLocalServer sipExportedTypes_QtNetwork[50]
#define sipClass_QLocalServer sipExportedTypes_QtNetwork[50]->u.td_wrapper_type

#define sipType_QLocalServer_SocketOption sipExportedTypes_QtNetwork[51]
#define sipEnum_QLocalServer_SocketOption sipExportedTypes_QtNetwork[51]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QLocalServer;

#define sipType_QLocalServer_SocketOptions sipExportedTypes_QtNetwork[52]
#define sipClass_QLocalServer_SocketOptions sipExportedTypes_QtNetwork[52]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QLocalServer_SocketOptions;

#define sipType_QLocalSocket sipExportedTypes_QtNetwork[53]
#define sipClass_QLocalSocket sipExportedTypes_QtNetwork[53]->u.td_wrapper_type

#define sipType_QLocalSocket_LocalSocketState sipExportedTypes_QtNetwork[55]
#define sipEnum_QLocalSocket_LocalSocketState sipExportedTypes_QtNetwork[55]->u.td_py_type

#define sipType_QLocalSocket_LocalSocketError sipExportedTypes_QtNetwork[54]
#define sipEnum_QLocalSocket_LocalSocketError sipExportedTypes_QtNetwork[54]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QLocalSocket;

#define sipType_QNetworkAccessManager sipExportedTypes_QtNetwork[58]
#define sipClass_QNetworkAccessManager sipExportedTypes_QtNetwork[58]->u.td_wrapper_type

#define sipType_QNetworkAccessManager_NetworkAccessibility sipExportedTypes_QtNetwork[59]
#define sipEnum_QNetworkAccessManager_NetworkAccessibility sipExportedTypes_QtNetwork[59]->u.td_py_type

#define sipType_QNetworkAccessManager_Operation sipExportedTypes_QtNetwork[60]
#define sipEnum_QNetworkAccessManager_Operation sipExportedTypes_QtNetwork[60]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkAccessManager;

#define sipType_QNetworkConfigurationManager sipExportedTypes_QtNetwork[70]
#define sipClass_QNetworkConfigurationManager sipExportedTypes_QtNetwork[70]->u.td_wrapper_type

#define sipType_QNetworkConfigurationManager_Capability sipExportedTypes_QtNetwork[72]
#define sipEnum_QNetworkConfigurationManager_Capability sipExportedTypes_QtNetwork[72]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkConfigurationManager;

#define sipType_QNetworkConfigurationManager_Capabilities sipExportedTypes_QtNetwork[71]
#define sipClass_QNetworkConfigurationManager_Capabilities sipExportedTypes_QtNetwork[71]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkConfigurationManager_Capabilities;

#define sipType_QNetworkConfiguration sipExportedTypes_QtNetwork[64]
#define sipClass_QNetworkConfiguration sipExportedTypes_QtNetwork[64]->u.td_wrapper_type

#define sipType_QNetworkConfiguration_BearerType sipExportedTypes_QtNetwork[65]
#define sipEnum_QNetworkConfiguration_BearerType sipExportedTypes_QtNetwork[65]->u.td_py_type

#define sipType_QNetworkConfiguration_StateFlag sipExportedTypes_QtNetwork[67]
#define sipEnum_QNetworkConfiguration_StateFlag sipExportedTypes_QtNetwork[67]->u.td_py_type

#define sipType_QNetworkConfiguration_Purpose sipExportedTypes_QtNetwork[66]
#define sipEnum_QNetworkConfiguration_Purpose sipExportedTypes_QtNetwork[66]->u.td_py_type

#define sipType_QNetworkConfiguration_Type sipExportedTypes_QtNetwork[69]
#define sipEnum_QNetworkConfiguration_Type sipExportedTypes_QtNetwork[69]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkConfiguration;

#define sipType_QNetworkConfiguration_StateFlags sipExportedTypes_QtNetwork[68]
#define sipClass_QNetworkConfiguration_StateFlags sipExportedTypes_QtNetwork[68]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkConfiguration_StateFlags;

#define sipType_QNetworkCookie sipExportedTypes_QtNetwork[73]
#define sipClass_QNetworkCookie sipExportedTypes_QtNetwork[73]->u.td_wrapper_type

#define sipType_QNetworkCookie_RawForm sipExportedTypes_QtNetwork[74]
#define sipEnum_QNetworkCookie_RawForm sipExportedTypes_QtNetwork[74]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkCookie;

#define sipType_QNetworkCookieJar sipExportedTypes_QtNetwork[75]
#define sipClass_QNetworkCookieJar sipExportedTypes_QtNetwork[75]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkCookieJar;

#define sipType_QNetworkDatagram sipExportedTypes_QtNetwork[76]
#define sipClass_QNetworkDatagram sipExportedTypes_QtNetwork[76]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkDatagram;

#define sipType_QNetworkDiskCache sipExportedTypes_QtNetwork[77]
#define sipClass_QNetworkDiskCache sipExportedTypes_QtNetwork[77]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkDiskCache;

#define sipType_QNetworkAddressEntry sipExportedTypes_QtNetwork[61]
#define sipClass_QNetworkAddressEntry sipExportedTypes_QtNetwork[61]->u.td_wrapper_type

#define sipType_QNetworkAddressEntry_DnsEligibilityStatus sipExportedTypes_QtNetwork[62]
#define sipEnum_QNetworkAddressEntry_DnsEligibilityStatus sipExportedTypes_QtNetwork[62]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkAddressEntry;

#define sipType_QNetworkInterface sipExportedTypes_QtNetwork[78]
#define sipClass_QNetworkInterface sipExportedTypes_QtNetwork[78]->u.td_wrapper_type

#define sipType_QNetworkInterface_InterfaceType sipExportedTypes_QtNetwork[81]
#define sipEnum_QNetworkInterface_InterfaceType sipExportedTypes_QtNetwork[81]->u.td_py_type

#define sipType_QNetworkInterface_InterfaceFlag sipExportedTypes_QtNetwork[79]
#define sipEnum_QNetworkInterface_InterfaceFlag sipExportedTypes_QtNetwork[79]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkInterface;

#define sipType_QNetworkInterface_InterfaceFlags sipExportedTypes_QtNetwork[80]
#define sipClass_QNetworkInterface_InterfaceFlags sipExportedTypes_QtNetwork[80]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkInterface_InterfaceFlags;

#define sipType_QNetworkProxy sipExportedTypes_QtNetwork[82]
#define sipClass_QNetworkProxy sipExportedTypes_QtNetwork[82]->u.td_wrapper_type

#define sipType_QNetworkProxy_Capability sipExportedTypes_QtNetwork[84]
#define sipEnum_QNetworkProxy_Capability sipExportedTypes_QtNetwork[84]->u.td_py_type

#define sipType_QNetworkProxy_ProxyType sipExportedTypes_QtNetwork[85]
#define sipEnum_QNetworkProxy_ProxyType sipExportedTypes_QtNetwork[85]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkProxy;

#define sipType_QNetworkProxy_Capabilities sipExportedTypes_QtNetwork[83]
#define sipClass_QNetworkProxy_Capabilities sipExportedTypes_QtNetwork[83]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkProxy_Capabilities;

#define sipType_QNetworkProxyQuery sipExportedTypes_QtNetwork[87]
#define sipClass_QNetworkProxyQuery sipExportedTypes_QtNetwork[87]->u.td_wrapper_type

#define sipType_QNetworkProxyQuery_QueryType sipExportedTypes_QtNetwork[88]
#define sipEnum_QNetworkProxyQuery_QueryType sipExportedTypes_QtNetwork[88]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkProxyQuery;

#define sipType_QNetworkProxyFactory sipExportedTypes_QtNetwork[86]
#define sipClass_QNetworkProxyFactory sipExportedTypes_QtNetwork[86]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkProxyFactory;

#define sipType_QNetworkReply sipExportedTypes_QtNetwork[89]
#define sipClass_QNetworkReply sipExportedTypes_QtNetwork[89]->u.td_wrapper_type

#define sipType_QNetworkReply_NetworkError sipExportedTypes_QtNetwork[90]
#define sipEnum_QNetworkReply_NetworkError sipExportedTypes_QtNetwork[90]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkReply;

#define sipType_QNetworkRequest sipExportedTypes_QtNetwork[91]
#define sipClass_QNetworkRequest sipExportedTypes_QtNetwork[91]->u.td_wrapper_type

#define sipType_QNetworkRequest_TransferTimeoutConstant sipExportedTypes_QtNetwork[98]
#define sipEnum_QNetworkRequest_TransferTimeoutConstant sipExportedTypes_QtNetwork[98]->u.td_py_type

#define sipType_QNetworkRequest_RedirectPolicy sipExportedTypes_QtNetwork[97]
#define sipEnum_QNetworkRequest_RedirectPolicy sipExportedTypes_QtNetwork[97]->u.td_py_type

#define sipType_QNetworkRequest_Priority sipExportedTypes_QtNetwork[96]
#define sipEnum_QNetworkRequest_Priority sipExportedTypes_QtNetwork[96]->u.td_py_type

#define sipType_QNetworkRequest_LoadControl sipExportedTypes_QtNetwork[95]
#define sipEnum_QNetworkRequest_LoadControl sipExportedTypes_QtNetwork[95]->u.td_py_type

#define sipType_QNetworkRequest_CacheLoadControl sipExportedTypes_QtNetwork[93]
#define sipEnum_QNetworkRequest_CacheLoadControl sipExportedTypes_QtNetwork[93]->u.td_py_type

#define sipType_QNetworkRequest_Attribute sipExportedTypes_QtNetwork[92]
#define sipEnum_QNetworkRequest_Attribute sipExportedTypes_QtNetwork[92]->u.td_py_type

#define sipType_QNetworkRequest_KnownHeaders sipExportedTypes_QtNetwork[94]
#define sipEnum_QNetworkRequest_KnownHeaders sipExportedTypes_QtNetwork[94]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkRequest;

#define sipType_QNetworkSession sipExportedTypes_QtNetwork[99]
#define sipClass_QNetworkSession sipExportedTypes_QtNetwork[99]->u.td_wrapper_type

#define sipType_QNetworkSession_UsagePolicy sipExportedTypes_QtNetwork[103]
#define sipEnum_QNetworkSession_UsagePolicy sipExportedTypes_QtNetwork[103]->u.td_py_type

#define sipType_QNetworkSession_SessionError sipExportedTypes_QtNetwork[100]
#define sipEnum_QNetworkSession_SessionError sipExportedTypes_QtNetwork[100]->u.td_py_type

#define sipType_QNetworkSession_State sipExportedTypes_QtNetwork[101]
#define sipEnum_QNetworkSession_State sipExportedTypes_QtNetwork[101]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkSession;

#define sipType_QNetworkSession_UsagePolicies sipExportedTypes_QtNetwork[102]
#define sipClass_QNetworkSession_UsagePolicies sipExportedTypes_QtNetwork[102]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkSession_UsagePolicies;

#define sipType_QOcspResponse sipExportedTypes_QtNetwork[105]
#define sipClass_QOcspResponse sipExportedTypes_QtNetwork[105]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QOcspResponse;

#define sipType_QPasswordDigestor sipExportedTypes_QtNetwork[108]
#define sipClass_QPasswordDigestor sipExportedTypes_QtNetwork[108]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QPasswordDigestor;

#define sipType_QSsl sipExportedTypes_QtNetwork[109]
#define sipClass_QSsl sipExportedTypes_QtNetwork[109]->u.td_wrapper_type

#define sipType_QSsl_SslOption sipExportedTypes_QtNetwork[114]
#define sipEnum_QSsl_SslOption sipExportedTypes_QtNetwork[114]->u.td_py_type

#define sipType_QSsl_SslProtocol sipExportedTypes_QtNetwork[116]
#define sipEnum_QSsl_SslProtocol sipExportedTypes_QtNetwork[116]->u.td_py_type

#define sipType_QSsl_AlternativeNameEntryType sipExportedTypes_QtNetwork[110]
#define sipEnum_QSsl_AlternativeNameEntryType sipExportedTypes_QtNetwork[110]->u.td_py_type

#define sipType_QSsl_KeyAlgorithm sipExportedTypes_QtNetwork[112]
#define sipEnum_QSsl_KeyAlgorithm sipExportedTypes_QtNetwork[112]->u.td_py_type

#define sipType_QSsl_EncodingFormat sipExportedTypes_QtNetwork[111]
#define sipEnum_QSsl_EncodingFormat sipExportedTypes_QtNetwork[111]->u.td_py_type

#define sipType_QSsl_KeyType sipExportedTypes_QtNetwork[113]
#define sipEnum_QSsl_KeyType sipExportedTypes_QtNetwork[113]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSsl;

#define sipType_QSsl_SslOptions sipExportedTypes_QtNetwork[115]
#define sipClass_QSsl_SslOptions sipExportedTypes_QtNetwork[115]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSsl_SslOptions;

#define sipType_QSslCertificate sipExportedTypes_QtNetwork[117]
#define sipClass_QSslCertificate sipExportedTypes_QtNetwork[117]->u.td_wrapper_type

#define sipType_QSslCertificate_PatternSyntax sipExportedTypes_QtNetwork[118]
#define sipEnum_QSslCertificate_PatternSyntax sipExportedTypes_QtNetwork[118]->u.td_py_type

#define sipType_QSslCertificate_SubjectInfo sipExportedTypes_QtNetwork[119]
#define sipEnum_QSslCertificate_SubjectInfo sipExportedTypes_QtNetwork[119]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslCertificate;

#define sipType_QSslCertificateExtension sipExportedTypes_QtNetwork[120]
#define sipClass_QSslCertificateExtension sipExportedTypes_QtNetwork[120]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslCertificateExtension;

#define sipType_QSslCipher sipExportedTypes_QtNetwork[121]
#define sipClass_QSslCipher sipExportedTypes_QtNetwork[121]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslCipher;

#define sipType_QSslConfiguration sipExportedTypes_QtNetwork[122]
#define sipClass_QSslConfiguration sipExportedTypes_QtNetwork[122]->u.td_wrapper_type

#define sipType_QSslConfiguration_NextProtocolNegotiationStatus sipExportedTypes_QtNetwork[123]
#define sipEnum_QSslConfiguration_NextProtocolNegotiationStatus sipExportedTypes_QtNetwork[123]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslConfiguration;

#define sipType_QSslDiffieHellmanParameters sipExportedTypes_QtNetwork[124]
#define sipClass_QSslDiffieHellmanParameters sipExportedTypes_QtNetwork[124]->u.td_wrapper_type

#define sipType_QSslDiffieHellmanParameters_Error sipExportedTypes_QtNetwork[125]
#define sipEnum_QSslDiffieHellmanParameters_Error sipExportedTypes_QtNetwork[125]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslDiffieHellmanParameters;

#define sipType_QSslEllipticCurve sipExportedTypes_QtNetwork[126]
#define sipClass_QSslEllipticCurve sipExportedTypes_QtNetwork[126]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslEllipticCurve;

#define sipType_QSslError sipExportedTypes_QtNetwork[127]
#define sipClass_QSslError sipExportedTypes_QtNetwork[127]->u.td_wrapper_type

#define sipType_QSslError_SslError sipExportedTypes_QtNetwork[128]
#define sipEnum_QSslError_SslError sipExportedTypes_QtNetwork[128]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslError;

#define sipType_QSslKey sipExportedTypes_QtNetwork[129]
#define sipClass_QSslKey sipExportedTypes_QtNetwork[129]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslKey;

#define sipType_QSslPreSharedKeyAuthenticator sipExportedTypes_QtNetwork[130]
#define sipClass_QSslPreSharedKeyAuthenticator sipExportedTypes_QtNetwork[130]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslPreSharedKeyAuthenticator;

#define sipType_QTcpSocket sipExportedTypes_QtNetwork[135]
#define sipClass_QTcpSocket sipExportedTypes_QtNetwork[135]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QTcpSocket;

#define sipType_QSslSocket sipExportedTypes_QtNetwork[131]
#define sipClass_QSslSocket sipExportedTypes_QtNetwork[131]->u.td_wrapper_type

#define sipType_QSslSocket_PeerVerifyMode sipExportedTypes_QtNetwork[132]
#define sipEnum_QSslSocket_PeerVerifyMode sipExportedTypes_QtNetwork[132]->u.td_py_type

#define sipType_QSslSocket_SslMode sipExportedTypes_QtNetwork[133]
#define sipEnum_QSslSocket_SslMode sipExportedTypes_QtNetwork[133]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslSocket;

#define sipType_QTcpServer sipExportedTypes_QtNetwork[134]
#define sipClass_QTcpServer sipExportedTypes_QtNetwork[134]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QTcpServer;

#define sipType_QUdpSocket sipExportedTypes_QtNetwork[136]
#define sipClass_QUdpSocket sipExportedTypes_QtNetwork[136]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtNetwork_QUdpSocket;

#define sipType_QVector_0100QOcspResponse sipExportedTypes_QtNetwork[138]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QVector_0100QOcspResponse;

#define sipType_QMap_0100QByteArray_0100QVariant sipExportedTypes_QtNetwork[56]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QMap_0100QByteArray_0100QVariant;

#define sipType_QVector_0100QSslEllipticCurve sipExportedTypes_QtNetwork[139]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QVector_0100QSslEllipticCurve;

#define sipType_QList_0100QSslCipher sipExportedTypes_QtNetwork[48]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSslCipher;

#define sipType_QList_0100QSslCertificateExtension sipExportedTypes_QtNetwork[47]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSslCertificateExtension;

#define sipType_QList_0100QSslCertificate sipExportedTypes_QtNetwork[46]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSslCertificate;

#define sipType_QList_0100QNetworkProxy sipExportedTypes_QtNetwork[44]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QNetworkProxy;

#define sipType_QList_0100QNetworkInterface sipExportedTypes_QtNetwork[43]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QNetworkInterface;

#define sipType_QList_0100QNetworkAddressEntry sipExportedTypes_QtNetwork[40]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QNetworkAddressEntry;

#define sipType_QList_0100QNetworkCookie sipExportedTypes_QtNetwork[42]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QNetworkCookie;

#define sipType_QList_0100QNetworkConfiguration sipExportedTypes_QtNetwork[41]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QNetworkConfiguration;

#define sipType_QVector_0100QHstsPolicy sipExportedTypes_QtNetwork[137]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QVector_0100QHstsPolicy;

#define sipType_QList_0100QSslError sipExportedTypes_QtNetwork[49]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSslError;

#define sipType_QList_0100QHostAddress sipExportedTypes_QtNetwork[39]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QHostAddress;

#define sipType_QPair_0100QHostAddress_1800 sipExportedTypes_QtNetwork[107]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QPair_0100QHostAddress_1800;

#define sipType_QList_0100QDnsTextRecord sipExportedTypes_QtNetwork[38]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsTextRecord;

#define sipType_QList_0100QDnsServiceRecord sipExportedTypes_QtNetwork[37]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsServiceRecord;

#define sipType_QList_0100QDnsMailExchangeRecord sipExportedTypes_QtNetwork[36]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsMailExchangeRecord;

#define sipType_QList_0100QDnsHostAddressRecord sipExportedTypes_QtNetwork[35]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsHostAddressRecord;

#define sipType_QList_0100QDnsDomainNameRecord sipExportedTypes_QtNetwork[34]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsDomainNameRecord;

#define sipType_QList_0600QPair_0100QByteArray_0100QByteArray sipExportedTypes_QtNetwork[45]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0600QPair_0100QByteArray_0100QByteArray;

#define sipType_QHash_0100QNetworkRequest_Attribute_0100QVariant sipExportedTypes_QtNetwork[20]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QHash_0100QNetworkRequest_Attribute_0100QVariant;

#define sipType_QMultiMap_0100QSsl_AlternativeNameEntryType_0100QString sipExportedTypes_QtNetwork[57]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QMultiMap_0100QSsl_AlternativeNameEntryType_0100QString;

#define sipType_Q_IPV6ADDR sipExportedTypes_QtNetwork[140]

extern sipMappedTypeDef sipTypeDef_QtNetwork_Q_IPV6ADDR;

#define sipType_QOcspRevocationReason sipExportedTypes_QtNetwork[106]
#define sipEnum_QOcspRevocationReason sipExportedTypes_QtNetwork[106]->u.td_py_type

#define sipType_QOcspCertificateStatus sipExportedTypes_QtNetwork[104]
#define sipEnum_QOcspCertificateStatus sipExportedTypes_QtNetwork[104]->u.td_py_type

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtNetwork;
extern sipExportedModuleDef sipModuleAPI_QtNetwork;
extern sipTypeDef *sipExportedTypes_QtNetwork[];

#define sipType_QObject sipImportedTypes_QtNetwork_QtCore[12].it_td
#define sipClass_QObject sipImportedTypes_QtNetwork_QtCore[12].it_td->u.td_wrapper_type

#define sipType_QIODevice sipImportedTypes_QtNetwork_QtCore[8].it_td
#define sipClass_QIODevice sipImportedTypes_QtNetwork_QtCore[8].it_td->u.td_wrapper_type

#define sipType_QByteArray sipImportedTypes_QtNetwork_QtCore[0].it_td
#define sipClass_QByteArray sipImportedTypes_QtNetwork_QtCore[0].it_td->u.td_wrapper_type

#define sipType_QEvent sipImportedTypes_QtNetwork_QtCore[6].it_td
#define sipClass_QEvent sipImportedTypes_QtNetwork_QtCore[6].it_td->u.td_wrapper_type

#define sipType_QTimerEvent sipImportedTypes_QtNetwork_QtCore[16].it_td
#define sipClass_QTimerEvent sipImportedTypes_QtNetwork_QtCore[16].it_td->u.td_wrapper_type

#define sipType_QChildEvent sipImportedTypes_QtNetwork_QtCore[1].it_td
#define sipClass_QChildEvent sipImportedTypes_QtNetwork_QtCore[1].it_td->u.td_wrapper_type

#define sipType_QCryptographicHash_Algorithm sipImportedTypes_QtNetwork_QtCore[2].it_td
#define sipEnum_QCryptographicHash_Algorithm sipImportedTypes_QtNetwork_QtCore[2].it_td->u.td_py_type

#define sipType_QDataStream sipImportedTypes_QtNetwork_QtCore[3].it_td
#define sipClass_QDataStream sipImportedTypes_QtNetwork_QtCore[3].it_td->u.td_wrapper_type

#define sipType_QDateTime sipImportedTypes_QtNetwork_QtCore[4].it_td
#define sipClass_QDateTime sipImportedTypes_QtNetwork_QtCore[4].it_td->u.td_wrapper_type

#define sipType_QDeadlineTimer sipImportedTypes_QtNetwork_QtCore[5].it_td
#define sipClass_QDeadlineTimer sipImportedTypes_QtNetwork_QtCore[5].it_td->u.td_wrapper_type

#define sipType_QIODevice_OpenMode sipImportedTypes_QtNetwork_QtCore[9].it_td
#define sipClass_QIODevice_OpenMode sipImportedTypes_QtNetwork_QtCore[9].it_td->u.td_wrapper_type

#define sipType_QMetaMethod sipImportedTypes_QtNetwork_QtCore[11].it_td
#define sipClass_QMetaMethod sipImportedTypes_QtNetwork_QtCore[11].it_td->u.td_wrapper_type

#define sipType_QRegExp_PatternSyntax sipImportedTypes_QtNetwork_QtCore[13].it_td
#define sipEnum_QRegExp_PatternSyntax sipImportedTypes_QtNetwork_QtCore[13].it_td->u.td_py_type

#define sipType_QUrl sipImportedTypes_QtNetwork_QtCore[17].it_td
#define sipClass_QUrl sipImportedTypes_QtNetwork_QtCore[17].it_td->u.td_wrapper_type

#define sipType_QUrl_ParsingMode sipImportedTypes_QtNetwork_QtCore[19].it_td
#define sipEnum_QUrl_ParsingMode sipImportedTypes_QtNetwork_QtCore[19].it_td->u.td_py_type

#define sipType_QUrl_ComponentFormattingOptions sipImportedTypes_QtNetwork_QtCore[18].it_td
#define sipClass_QUrl_ComponentFormattingOptions sipImportedTypes_QtNetwork_QtCore[18].it_td->u.td_wrapper_type

#define sipType_QVariant sipImportedTypes_QtNetwork_QtCore[20].it_td
#define sipClass_QVariant sipImportedTypes_QtNetwork_QtCore[20].it_td->u.td_wrapper_type

#define sipType_QList_0100QByteArray sipImportedTypes_QtNetwork_QtCore[10].it_td

#define sipType_QHash_0100QString_0100QVariant sipImportedTypes_QtNetwork_QtCore[7].it_td

#define sipType_QStringList sipImportedTypes_QtNetwork_QtCore[15].it_td

#define sipType_QString sipImportedTypes_QtNetwork_QtCore[14].it_td

#define sipType_quintptr sipImportedTypes_QtNetwork_QtCore[22].it_td

#define sipType_qintptr sipImportedTypes_QtNetwork_QtCore[21].it_td

#define sipType_QOcspRevocationReason sipExportedTypes_QtNetwork[106]
#define sipEnum_QOcspRevocationReason sipExportedTypes_QtNetwork[106]->u.td_py_type

#define sipType_QOcspCertificateStatus sipExportedTypes_QtNetwork[104]
#define sipEnum_QOcspCertificateStatus sipExportedTypes_QtNetwork[104]->u.td_py_type
extern sipImportedTypeDef sipImportedTypes_QtNetwork_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtNetwork_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *,sipTypeDef *);
extern sip_qt_metaobject_func sip_QtNetwork_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *,sipTypeDef *,QMetaObject::Call,int,void **);
extern sip_qt_metacall_func sip_QtNetwork_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtNetwork_qt_metacast;
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhostinfo.sip"
// Imports from QtCore.
typedef sipErrorState (*pyqt5_qtnetwork_get_connection_parts_t)(PyObject *, QObject *, const char *, bool, QObject **, QByteArray &);
extern pyqt5_qtnetwork_get_connection_parts_t pyqt5_qtnetwork_get_connection_parts;
#line 3209 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipAPIQtNetwork.h"

#endif
